# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_baidu_lian_xi_qu_dian_nao_pei_xun_1643390077():
    verify_serp_parsing(
        "https://web.archive.org/web/20220128171437id_/http://zhannei.baidu.com/cse/site?q=%E6%BF%82%E6%BA%AA%E5%8C%BA%E7%94%B5%E8%84%91%E5%9F%B9%E8%AE%AD&p=0&cc=actwhite.cn",
        "baidu",
    )


def test_parse_query_baidu_mao_kui_lu_mao_cong_cong_mao_ning_kui_mao_dan_dan_mang_lu_1549835769():
    verify_serp_parsing(
        "https://web.archive.org/web/20190210215609id_/https://www.baidu.com/s?wd=%E8%8C%85%E8%81%B5%E9%A9%B4%E8%8C%85%E8%81%A1%E8%81%A6%E7%8C%AB%E8%81%B9%E8%81%B5%E7%8C%AB%E8%81%B8%E8%81%B8%E5%BF%99%E5%8D%A4&oq=%E8%8C%85%E8%81%B5%E9%A9%B4%E8%8C%85%E8%81%A1%E8%81%A6%E7%8C%AB%E8%81%B9%E8%81%B5%E7%8C%AB%E8%81%B8%E8%81%B8%E5%BF%99%E5%8D%A4&ie=utf-8&rsv_pq=87216f54001538da&rsv_t=19e3cg%2FMtz92Yq09CCIJaki1%2BUL6aGQ6QJQBgVzprgVnaNRLdUeIL6teIzY&rqlang=cn&nojs=1&bqid=87216f54001538da",
        "baidu",
    )


def test_parse_query_baidu_e_eeeae_1569971117():
    verify_serp_parsing(
        "https://web.archive.org/web/20191001230517id_/https://www.baidu.com/s?wd=%C3%A9%C2%98%C2%BF%C3%A9%C2%87%C2%8C%C3%A8%C2%9C%C2%98%C3%A8%C2%9B%C2%9B%C3%A6%C2%B1",
        "baidu",
    )


def test_parse_query_baidu_e_eeeae_1544443888():
    verify_serp_parsing(
        "https://web.archive.org/web/20181210121128id_/https://www.baidu.com/s?wd=%C3%A9%C2%98%C2%BF%C3%A9%C2%87%C2%8C%C3%A8%C2%9C%C2%98%C3%A8%C2%9B%C2%9B%C3%A6%C2%B1",
        "baidu",
    )


def test_parse_query_baidu_mao_kui_lu_mao_cong_cong_mao_ning_kui_mao_dan_dan_mang_lu_1564025418():
    verify_serp_parsing(
        "https://web.archive.org/web/20190725033018id_/https://www.baidu.com/s?wd=%E8%8C%85%E8%81%B5%E9%A9%B4%E8%8C%85%E8%81%A1%E8%81%A6%E7%8C%AB%E8%81%B9%E8%81%B5%E7%8C%AB%E8%81%B8%E8%81%B8%E5%BF%99%E5%8D%A4&oq=%E8%8C%85%E8%81%B5%E9%A9%B4%E8%8C%85%E8%81%A1%E8%81%A6%E7%8C%AB%E8%81%B9%E8%81%B5%E7%8C%AB%E8%81%B8%E8%81%B8%E5%BF%99%E5%8D%A4&ie=utf-8&rsv_pq=d25fbc8d000b4e82&rsv_t=fc63O4O%2FKyZwE5v5jDt8lv18HT8dHQWj2Go%2BcrYpMDHze7HivVjCvAF%2F6R0&rqlang=cn&nojs=1&bqid=d25fbc8d000b4e82",
        "baidu",
    )


def test_parse_query_baidu_e_eeeae_1547510808():
    verify_serp_parsing(
        "https://web.archive.org/web/20190115000648id_/https://www.baidu.com/s?wd=%C3%A9%C2%98%C2%BF%C3%A9%C2%87%C2%8C%C3%A8%C2%9C%C2%98%C3%A8%C2%9B%C2%9B%C3%A6%C2%B1",
        "baidu",
    )


def test_parse_query_baidu_e_eeeae_1567878230():
    verify_serp_parsing(
        "https://web.archive.org/web/20190907174350id_/https://www.baidu.com/s?wd=%C3%A9%C2%98%C2%BF%C3%A9%C2%87%C2%8C%C3%A8%C2%9C%C2%98%C3%A8%C2%9B%C2%9B%C3%A6%C2%B1",
        "baidu",
    )


def test_parse_query_baidu_mao_kui_lu_mao_cong_cong_mao_ning_kui_mao_dan_dan_mang_lu_1553838201():
    verify_serp_parsing(
        "https://web.archive.org/web/20190329054321id_/https://www.baidu.com/s?wd=%E8%8C%85%E8%81%B5%E9%A9%B4%E8%8C%85%E8%81%A1%E8%81%A6%E7%8C%AB%E8%81%B9%E8%81%B5%E7%8C%AB%E8%81%B8%E8%81%B8%E5%BF%99%E5%8D%A4&oq=%E8%8C%85%E8%81%B5%E9%A9%B4%E8%8C%85%E8%81%A1%E8%81%A6%E7%8C%AB%E8%81%B9%E8%81%B5%E7%8C%AB%E8%81%B8%E8%81%B8%E5%BF%99%E5%8D%A4&ie=utf-8&rsv_pq=ce502b7c00017f4e&rsv_t=429fdL0VhHNPGYvy2nJwvedkWEHrVvYOK1YdtSoHeKxoh77YPXsd%2FA%2FeSOo&rqlang=cn&nojs=1&bqid=ce502b7c00017f4e",
        "baidu",
    )


def test_parse_query_baidu_e_eeeae_1558963051():
    verify_serp_parsing(
        "https://web.archive.org/web/20190527131731id_/https://www.baidu.com/s?wd=%C3%A9%C2%98%C2%BF%C3%A9%C2%87%C2%8C%C3%A8%C2%9C%C2%98%C3%A8%C2%9B%C2%9B%C3%A6%C2%B1",
        "baidu",
    )


def test_parse_query_baidu_zhong_guo_lian_tong_smsc_1372160086():
    verify_serp_parsing(
        "https://web.archive.org/web/20130625113446id_/http://www.baidu.com/s?wd=%E4%B8%AD%E5%9B%BD%E8%81%94%E9%80%9A%20smsc&tn=baidufir",
        "baidu",
    )


def test_parse_query_baidu_sexinsex_1_2_1213858525():
    verify_serp_parsing(
        "https://web.archive.org/web/20080619065525id_/http://www.baidu.com:80/s?wd=sexinsex%B4%F3%C2%BD%C3%E2%B7%D1%C8%EB%BF%DA&lm=0&si=&rn=10&ie=gb2312&ct=0&cl=3&f=1&rsp=9",
        "baidu",
    )


def test_parse_query_baidu_mao_ning_kui_mao_dan_dan_mang_long_lou_mang_lu_shikato_1537858258():
    verify_serp_parsing(
        "https://web.archive.org/web/20180925065058id_/https://www.baidu.com/s?wd=%E7%8C%AB%E8%81%B9%E8%81%B5%E7%8C%AB%E8%81%B8%E8%81%B8%E6%B0%93%E9%99%87%E6%90%82%E6%B0%93%E8%B5%82%E8%81%A2&oq=%E7%8C%AB%E8%81%B9%E8%81%B5%E7%8C%AB%E8%81%B8%E8%81%B8%E6%B0%93%E9%99%87%E6%90%82%E6%B0%93%E8%B5%82%E8%81%A2&ie=utf-8&rsv_pq=9f20a69b00016e59&rsv_t=4e92hBffxcH%2BZ67tApMjf2jcV67jPo6GzU42zK0wG0%2Ff6aF%2F68rl5AeYfy8&rqlang=cn&nojs=1&bqid=9f20a69b00016e59",
        "baidu",
    )


def test_parse_query_baidu_long_shi_liang_1639014949():
    verify_serp_parsing(
        "https://web.archive.org/web/20211209015549id_/https://wenku.baidu.com/search?lm=0&od=0&ie=utf-8&dyTabStr=MCwzLDQsMSw2LDUsNyw4LDIsOQ%3D%3D&word=%22%E9%BE%8D%E4%B8%96%E6%A8%91%22",
        "baidu",
    )


def test_parse_query_baidu_mao_kui_lu_mao_cong_cong_mao_ning_kui_mao_dan_dan_mang_lu_1558979495():
    verify_serp_parsing(
        "https://web.archive.org/web/20190527175135id_/https://www.baidu.com/s?wd=%E8%8C%85%E8%81%B5%E9%A9%B4%E8%8C%85%E8%81%A1%E8%81%A6%E7%8C%AB%E8%81%B9%E8%81%B5%E7%8C%AB%E8%81%B8%E8%81%B8%E5%BF%99%E5%8D%A4&oq=%E8%8C%85%E8%81%B5%E9%A9%B4%E8%8C%85%E8%81%A1%E8%81%A6%E7%8C%AB%E8%81%B9%E8%81%B5%E7%8C%AB%E8%81%B8%E8%81%B8%E5%BF%99%E5%8D%A4&ie=utf-8&rsv_pq=8904574900082530&rsv_t=9bbeaAnORF%2BIrKzJVAMdIO%2B5XlN26aMHDddm0oqJPVHpCwMWT1aVQIDgsHA&rqlang=cn&nojs=1&bqid=8904574900082530",
        "baidu",
    )


def test_parse_query_baidu_eru_1525597474():
    verify_serp_parsing(
        "https://web.archive.org/web/20180506090434id_/http://tieba.baidu.com:80/f?kw=eru&ie=utf-8",
        "baidu",
    )


def test_parse_query_baidu_e_eeeae_1554431691():
    verify_serp_parsing(
        "https://web.archive.org/web/20190405023451id_/https://www.baidu.com/s?wd=%C3%A9%C2%98%C2%BF%C3%A9%C2%87%C2%8C%C3%A8%C2%9C%C2%98%C3%A8%C2%9B%C2%9B%C3%A6%C2%B1",
        "baidu",
    )


def test_parse_query_baidu_lian_yun_gang_qi_yang_yue_zi_hui_suo_zhong_xin_jing_zhun_ke_hu_ying_xiao_key668_cn_1537259978():
    verify_serp_parsing(
        "https://web.archive.org/web/20180918083938id_/https://www.baidu.com/s?wd=%E8%BF%9E%E4%BA%91%E6%B8%AF%E9%AA%90%E6%89%AC%E6%9C%88%E5%AD%90%E4%BC%9A%E6%89%80%E4%B8%AD%E5%BF%83%E7%B2%BE%E5%87%86%E5%AE%A2%E6%88%B7%E8%90%A5%E9%94%80key668.cn",
        "baidu",
    )


def test_parse_query_baidu_long_feng_qu_qi_quan_qi_huo_pei_xun_1642853767():
    verify_serp_parsing(
        "https://web.archive.org/web/20220122121607id_/http://zhannei.baidu.com/cse/site?q=%E9%BE%99%E5%87%A4%E5%8C%BA%E6%9C%9F%E6%9D%83%E6%9C%9F%E8%B4%A7%E5%9F%B9%E8%AE%AD&p=0&cc=actunderstand.cn",
        "baidu",
    )


def test_parse_query_baidu_e_eeeae_1522165852():
    verify_serp_parsing(
        "https://web.archive.org/web/20180327155052id_/https://www.baidu.com/s?wd=%C3%A9%C2%98%C2%BF%C3%A9%C2%87%C2%8C%C3%A8%C2%9C%C2%98%C3%A8%C2%9B%C2%9B%C3%A6%C2%B1",
        "baidu",
    )


def test_parse_query_baidu_shang_hai_11xuan_5ding_dan_wei_xin_weiwei776699_1545685930():
    verify_serp_parsing(
        "https://web.archive.org/web/20181224211210id_/https://wenku.baidu.com/search?word=%E4%B8%8A%E6%B5%B711%E9%80%895%E5%AE%9A%E8%83%86%2B%E3%80%96%E5%BE%AE%E4%BF%A1weiwei776699%E3%80%97%E2%94%A0&ie=utf-8&lm=0&od=0",
        "baidu",
    )
