# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_etsy_embroidery_kit_1375805089():
    verify_serp_parsing(
        "https://web.archive.org/web/20130806160449id_/http://www.etsy.com/search?includes[]=tags&q=embroidery+kit",
        "etsy",
    )


def test_parse_query_etsy_sundress_1374472455():
    verify_serp_parsing(
        "https://web.archive.org/web/20130722055415id_/http://www.etsy.com:80/search?includes[]=tags&q=Sundress",
        "etsy",
    )


def test_parse_query_etsy_storage_and_organization_1632881953():
    verify_serp_parsing(
        "https://web.archive.org/web/20210929021913id_/https://www.etsy.com/search?q=storage+and+organization&mosv=sese&moci=1040853552759&mosi=1027452046072&ref=hp_bubbles_Fall21_US_GB_CA_FR_DE&anchor_listing_id=830217119",
        "etsy",
    )


def test_parse_query_etsy_andrew_kim_1566153959():
    verify_serp_parsing(
        "https://web.archive.org/web/20190818184559id_/https://www.etsy.com/search?q=Andrew+Kim&explicit=1&order=date_desc",
        "etsy",
    )


def test_parse_query_etsy_pendants_1667648711():
    verify_serp_parsing(
        "https://web.archive.org/web/20221105114511id_/https://www.etsy.com/search?locale_override=USD%7Cen-US%7CUS&explicit=1&q=pendants&anchor_listing_id=200491601&gf_type=interest",
        "etsy",
    )


def test_parse_query_etsy_pacifier_1336437253():
    verify_serp_parsing(
        "https://web.archive.org/web/20120508003413id_/http://www.etsy.com:80/search?includes[]=tags&q=pacifier",
        "etsy",
    )


def test_parse_query_etsy_invitation_1367234841():
    verify_serp_parsing(
        "https://web.archive.org/web/20130429112721id_/http://www.etsy.com/search?q=invitation&ref=exp_listing",
        "etsy",
    )


def test_parse_query_etsy_yan_dong_kuai_le_shi_fen_shou_ji_ban_jia_wei_xin_xw639_2018_1537911471():
    verify_serp_parsing(
        "https://web.archive.org/web/20180925213751id_/https://www.etsy.com/search?q=%E5%B9%BF%E4%B8%9C%E5%BF%AB%E4%B9%90%E5%8D%81%E5%88%86%E6%89%8B%E6%9C%BA%E7%89%88%E5%8A%A0%E5%BE%AE%E3%80%85%E4%BF%A1xw639-2018%E2%99%80",
        "etsy",
    )


def test_parse_query_etsy_hard_plastic_1333819223():
    verify_serp_parsing(
        "https://web.archive.org/web/20120407172023id_/http://www.etsy.com:80/search?includes[]=materials&q=hard+plastic",
        "etsy",
    )


def test_parse_query_etsy_small_animal_1378528595():
    verify_serp_parsing(
        "https://web.archive.org/web/20130907043635id_/http://www.etsy.com/search?includes[]=tags&q=Small+Animal",
        "etsy",
    )
