# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_cnn_kindly_check_1642508434():
    verify_serp_parsing(
        "https://web.archive.org/web/20220118122034id_/https://edition.cnn.com/search?q=kindly%20check",
        "cnn",
    )


def test_parse_query_cnn_achievable_possibility_1642416655():
    verify_serp_parsing(
        "https://web.archive.org/web/20220117105055id_/https://edition.cnn.com/search?q=achievable%20possibility",
        "cnn",
    )


def test_parse_query_cnn_apple_watch_2016_1662575890():
    verify_serp_parsing(
        "https://web.archive.org/web/20220907183810id_/https://www.cnn.com/search?q=apple%20watch%202016",
        "cnn",
    )


def test_parse_query_cnn_march_4_1633908556():
    verify_serp_parsing(
        "https://web.archive.org/web/20211010232916id_/https://www.cnn.com/search?q=March+4",
        "cnn",
    )


def test_parse_query_cnn_dxa_1634498874():
    verify_serp_parsing(
        "https://web.archive.org/web/20211017192754id_/https://www.cnn.com/search?q=dxa",
        "cnn",
    )


def test_parse_query_cnn_trigger_1638271567():
    verify_serp_parsing(
        "https://web.archive.org/web/20211130112607id_/https://edition.cnn.com/search?q=trigger",
        "cnn",
    )


def test_parse_query_cnn_wright_1616229078():
    verify_serp_parsing(
        "https://web.archive.org/web/20210320083118id_/https://www.cnn.com/search?size=10&q=Wright",
        "cnn",
    )


def test_parse_query_cnn_skilled_1643388398():
    verify_serp_parsing(
        "https://web.archive.org/web/20220128164638id_/https://edition.cnn.com/search?q=skilled",
        "cnn",
    )


def test_parse_query_cnn_biteukoinsaryeomyeon_www_99m_kr_bei_biteukoinsaryelie_biteukoinsaeobbbiteukoinsaeobjadeungrog_biteukoinsayongbangbeob8reduplicate_1647153716():
    verify_serp_parsing(
        "https://web.archive.org/web/20220313064156id_/https://edition.cnn.com/search?q=%EB%B9%84%ED%8A%B8%EC%BD%94%EC%9D%B8%EC%82%AC%EB%A0%A4%EB%A9%B4%28WWW%C2%B899M%C2%B8KR%29%E5%AD%9B%EB%B9%84%ED%8A%B8%EC%BD%94%EC%9D%B8%EC%82%AC%EB%A1%80%E5%8A%BD%EB%B9%84%ED%8A%B8%EC%BD%94%EC%9D%B8%EC%82%AC%EC%97%85%E0%AA%AC%EB%B9%84%ED%8A%B8%EC%BD%94%EC%9D%B8%EC%82%AC%EC%97%85%EC%9E%90%EB%93%B1%EB%A1%9D%E2%97%81%EB%B9%84%ED%8A%B8%EC%BD%94%EC%9D%B8%EC%82%AC%EC%9A%A9%EB%B0%A9%EB%B2%958%E2%83%A3reduplicate/",
        "cnn",
    )


def test_parse_query_cnn_north_dakota_coronavirus_1632793271():
    verify_serp_parsing(
        "https://web.archive.org/web/20210928014111id_/https://www.cnn.com/search?q=North+Dakota+coronavirus",
        "cnn",
    )
