# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_wikimedia_figures_in_theatrical_costumes_claude_gillot_1673_1722_class_photo_description_french_painter_drawer_1632572254():
    verify_serp_parsing(
        "https://web.archive.org/web/20210925121734id_/https://www.wikidata.org/w/index.php?title=Special:Search&search=Figures+in+Theatrical+Costumes+%0A%0A%0AClaude+Gillot%0A%26nbsp%3B%281673%26ndash%3B1722%29%26nbsp%3B%26nbsp%3B%0A%0A%0A%7Cclass%3Dphoto%0A%0A%0ADescription%0AFrench+painter%2C+drawer+and+graphic+artist%0A%0ADate+of+birth%2Fdeath%0A%0A28+April+1673+%2F+27+April+1673%26nbsp%3B%0A4+May+1722%26nbsp%3B%0A%0ALocation+of+birth%2Fdeath%0A%0ALangres%0AParis%0A%0AWork+location%0A%0AParis%26nbsp%3B%0A%0AAuthority+control%0A%0A%2A%3A+Q559969%0A%2AVIAF%3A%26thinsp%3B27335846%0A%2AISNI%3A%26thinsp%3B0000+0001+2277+7433%0A%2AULAN%3A%26thinsp%3B500115197%0A%2ALCCN%3A%26thinsp%3Bnr93039721%0A%2AWGA%3A%26thinsp%3BGILLOT%2C+Claude%0A%2AWorldCat%0A%0A%0A%0A%0A%0A%0A%0A%0A%0AAntoine+Watteau%0A%26nbsp%3B%281684%26ndash%3B1721%29%26nbsp%3B%26nbsp%3B%26nbsp%3B%0A%0A%0A%7Cclass%3Dphoto%0A%0A%0AAlternative+names%0A%0AJean-Antoine+Watteau%0A%0ADescription%0AFrench+painter%2C+graphic+artist%2C+drawer%2C+artist%2C+printmaker+and+draftsperson%0A%0ADate+of+birth%2Fdeath%0A%0A10+October+1684%26nbsp%3B%0A18+July+1721%26nbsp%3B%0A%0ALocation+of+birth%2Fdeath%0A%0AValenciennes%0ANogent-sur-Marne%0A%0AWork+location%0A%0AParis+%28after+1702+%29%2C+Valenciennes+%281709-1710%29%2C+London+%281719-1720%29%0A%0AAuthority+control%0A%0A%2A%3A+Q183221%0A%2AVIAF%3A%26thinsp%3B46882028%0A%2AISNI%3A%26thinsp%3B0000+0001+2131+1877%0A%2AULAN%3A%26thinsp%3B500032644%0A%2ALCCN%3A%26thinsp%3Bn50043693%0A%2ANLA%3A%26thinsp%3B36213816%0A%2AWorldCat%0A%0A%0A%0A%0A%0A+10.45.15+haswbstatement%3AP195%3DQ160236&profile=advanced&fulltext=1&ns0=1",
        "wikimedia",
    )


def test_parse_query_wikimedia_group_portrait_on_doorstep_collins_tudor_washington_1898_1970_photographer_75426_object_number_haswb_1629837781():
    verify_serp_parsing(
        "https://web.archive.org/web/20210824204301id_/https://www.wikidata.org/w/index.php?search=(Group+portrait+on+doorstep)+Collins,+Tudor+Washington,+1898-1970,+photographer+75426+(object+number)+haswbstatement:P195%3DQ758657&title=Special:Search&profile=advanced&fulltext=1&ns0=1",
        "wikimedia",
    )


def test_parse_query_wikimedia_mou_lin_han_site_pku_edu_cn_1576868395():
    verify_serp_parsing(
        "https://web.archive.org/web/20191220185955id_/https://en.wikipedia.org/w/index.php?title=Special%3ASearch&profile=images&search=%E7%89%9F%E6%9E%97%E7%BF%B0+site%3Apku.edu.cn&fulltext=1&ns0=1",
        "wikimedia",
    )


def test_parse_query_wikimedia_nito_1655733503():
    verify_serp_parsing(
        "https://web.archive.org/web/20220620135823id_/https://commons.wikimedia.org/w/index.php?title=Special%3AMediaSearch&search=Nit%C6%A1",
        "wikimedia",
    )


def test_parse_query_wikimedia_prob_1543207125():
    verify_serp_parsing(
        "https://web.archive.org/web/20181126043845id_/https://zh.wikipedia.org/w/index.php?search=prob&title=Special%3A%E6%90%9C%E7%B4%A2&profile=default&fulltext=1",
        "wikimedia",
    )


def test_parse_query_wikimedia_ao_xian_yu_le_du_bo_ping_tai_1430758639():
    verify_serp_parsing(
        "https://web.archive.org/web/20150504165719id_/http://zh.wikipedia.org/w/index.php?search=%E6%BE%B3%E7%BA%BF%E5%A8%B1%E4%B9%90%E8%B5%8C%E5%8D%9A%E5%B9%B3%E5%8F%B0",
        "wikimedia",
    )


def test_parse_query_wikimedia_zao_can_bao_zi_jia_meng_www_baidu_com_aaaa_4ws_2018nian_8yue_4ri_21shi_19fen_39miao_1537939782():
    verify_serp_parsing(
        "https://web.archive.org/web/20180926052942id_/https://zh.wikipedia.org/w/index.php?search=%E6%97%A9%E9%A4%90%E5%8C%85%E5%AD%90%E5%8A%A0%E7%9B%9F%20www.baidu.com/aaaa%204ws%202018%E5%B9%B48%E6%9C%884%E6%97%A521%E6%97%B619%E5%88%8639%E7%A7%92",
        "wikimedia",
    )


def test_parse_query_wikimedia_oxygen_1596274448():
    verify_serp_parsing(
        "https://web.archive.org/web/20200801093408id_/https://commons.wikimedia.org/w/index.php?title=Special:Search&search=Oxygen&ns0=1&ns6=1&ns12=1&ns14=1&ns100=1&ns106=1",
        "wikimedia",
    )


def test_parse_query_wikimedia_recaptchalogo_svg_1509131182():
    verify_serp_parsing(
        "https://web.archive.org/web/20171027190622id_/https://www.wikidata.org/w/index.php?title=Special:Search&profile=images&search=RecaptchaLogo.svg&fulltext=1",
        "wikimedia",
    )


def test_parse_query_wikimedia_la_dian_zi_ji_1517046182():
    verify_serp_parsing(
        "https://web.archive.org/web/20180127094302id_/https://zh.wikipedia.org/w/index.php?title=Special:%E6%90%9C%E7%B4%A2&search=%E6%8B%89%E9%9B%BB%E5%AD%90%E5%9F%BA",
        "wikimedia",
    )
