# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_bongacams_facial_1578106424():
    verify_serp_parsing(
        "https://web.archive.org/web/20200104025344id_/https://en.bongacams.com/male/tags/facial",
        "bongacams",
    )


def test_parse_query_bongacams_hd_plus_1576443879():
    verify_serp_parsing(
        "https://web.archive.org/web/20191215210439id_/https://bongacams.com/male/tags/hd-plus",
        "bongacams",
    )


def test_parse_query_bongacams_camshow_1653633300():
    verify_serp_parsing(
        "https://web.archive.org/web/20220527063500id_/https://bongacams.com/female/tags/camshow",
        "bongacams",
    )


def test_parse_query_bongacams_stripping_1623091287():
    verify_serp_parsing(
        "https://web.archive.org/web/20210607184127id_/https://bongacams.com/female/tags/stripping?page=3",
        "bongacams",
    )


def test_parse_query_bongacams_teasing_1635992326():
    verify_serp_parsing(
        "https://web.archive.org/web/20211104021846id_/https://bongacams.com/couples/tags/teasing",
        "bongacams",
    )


def test_parse_query_bongacams_asslicking_1623701105():
    verify_serp_parsing(
        "https://web.archive.org/web/20210614200505id_/https://bongacams.com/couples/tags/asslicking",
        "bongacams",
    )


def test_parse_query_bongacams_fucking_1577494848():
    verify_serp_parsing(
        "https://web.archive.org/web/20191228010048id_/https://en.bongacams.com/male/tags/fucking",
        "bongacams",
    )


def test_parse_query_bongacams_cock_sucking_1617355851():
    verify_serp_parsing(
        "https://web.archive.org/web/20210402093051id_/https://bongacams.com/male/tags/cock-sucking?page=2",
        "bongacams",
    )


def test_parse_query_bongacams_massage_1604010948():
    verify_serp_parsing(
        "https://web.archive.org/web/20201029223548id_/https://en.bongacams.com/male/tags/massage",
        "bongacams",
    )


def test_parse_query_bongacams_stripping_1648087966():
    verify_serp_parsing(
        "https://web.archive.org/web/20220324021246id_/https://en.bongacams.com/couples/tags/stripping",
        "bongacams",
    )
