# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_reddit_teleperformance_1260472045():
    verify_serp_parsing(
        "https://web.archive.org/web/20091210190725id_/http://www.reddit.com:80/search?q=%22teleperformance%22&KeepThis=true&TB_iframe=true&height=550&width=800",
        "reddit",
    )


def test_parse_query_reddit_3ds_1364668924():
    verify_serp_parsing(
        "https://web.archive.org/web/20130330184204id_/http://en.reddit.com/search?q=3ds",
        "reddit",
    )


def test_parse_query_reddit_jailbait_1376244913():
    verify_serp_parsing(
        "https://web.archive.org/web/20130811181513id_/http://www.reddit.com/search?q=jailbait",
        "reddit",
    )


def test_parse_query_reddit_german_nebelmittelwurfanlage_1664557458():
    verify_serp_parsing(
        "https://web.archive.org/web/20220930170418id_/https://www.reddit.com/search/?q=german+nebelmittelwurfanlage&sort=comments&t=all",
        "reddit",
    )


def test_parse_query_reddit_supermoon_1403887175():
    verify_serp_parsing(
        "https://web.archive.org/web/20140627163935id_/http://fr.reddit.com/search?q=supermoon",
        "reddit",
    )


def test_parse_query_reddit_touch_meme_1663170731():
    verify_serp_parsing(
        "https://web.archive.org/web/20220914155211id_/https://www.reddit.com/search/?q=touch%20meme&include_over_18=1&type=link",
        "reddit",
    )


def test_parse_query_reddit_flair_already_posted_https_redd_it_xamfzl_1667030236():
    verify_serp_parsing(
        "https://web.archive.org/web/20221029075716id_/https://old.reddit.com/search/?q=flair%3A%22already+posted+https%3A%2F%2Fredd.it%2Fxamfzl%22&sort=comments&type=comment",
        "reddit",
    )


def test_parse_query_reddit_how_can_i_access_nature_com_articles_1666041985():
    verify_serp_parsing(
        "https://web.archive.org/web/20221017212625id_/https://www.reddit.com/search/?q=How%20Can%20I%20Access%20Nature.com%20Articles%3F&sort=top&type=comment",
        "reddit",
    )


def test_parse_query_reddit_b7_1650853917():
    verify_serp_parsing(
        "https://web.archive.org/web/20220425023157id_/https://www.reddit.com/search/?q=b7",
        "reddit",
    )


def test_parse_query_reddit_typetest_10fastfingers_1663797626():
    verify_serp_parsing(
        "https://web.archive.org/web/20220921220026id_/https://old.reddit.com/search?q=typetest+10fastfingers&restrict_sr=&sort=relevance&t=all",
        "reddit",
    )
