<template>
    <div class="footer">
      &copy; 2024 Webis Group |
      <a href="https://webis.de/people.html" class="white--text">Contact</a> |
      <a href="https://webis.de/legal.html" class="white--text">Imprint</a> |
      <a href="https://webis.de/legal.html" class="white--text">Privacy</a>
    </div>
  </template>
  
  <style>
  .footer {
    text-align: center;
    padding: 16px;
    width: 100%;
    background: #fff;
  }
  </style>
  