# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_chefkoch_spaghetti_eis_torte_1342866905():
    verify_serp_parsing(
        "https://web.archive.org/web/20120721103505id_/http://www.chefkoch.de:80/rs/s0/,spaghetti+eis+torte/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_walnussl_dressing_1403236002():
    verify_serp_parsing(
        "https://web.archive.org/web/20140620034642id_/http://www.chefkoch.de:80/rs/s0/,walnuss%F6l+dressing/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_eier_spinat_pilze_1200619371():
    verify_serp_parsing(
        "https://web.archive.org/web/20080118012251id_/http://www.chefkoch.de:80/rs/s0/eier+spinat+pilze/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_tomaten_mozarella_reis_1317162887():
    verify_serp_parsing(
        "https://web.archive.org/web/20110927223447id_/http://www.chefkoch.de:80/rs/s0/%2C+tomaten+mozarella+reis/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_spargel_m_soe_1280861753():
    verify_serp_parsing(
        "https://web.archive.org/web/20100803185553id_/http://www.chefkoch.de:80/rs/s0/spargel+m.+so%DFe/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_spanische_salat_1192556276():
    verify_serp_parsing(
        "https://web.archive.org/web/20071016173756id_/http://www.chefkoch.de:80/rs/s0/spanische+salat/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_thailndisch_1313401080():
    verify_serp_parsing(
        "https://web.archive.org/web/20110815093800id_/http://www.chefkoch.de:80/rs/s0/%2Cthail%E4ndisch/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_hhnchen_warme_1303285108():
    verify_serp_parsing(
        "https://web.archive.org/web/20110420073828id_/http://www.chefkoch.de:80/rs/s0/%2Ch%E4hnchen+warme/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_spaghettitorte_vom_blech_1369060560():
    verify_serp_parsing(
        "https://web.archive.org/web/20130520143600id_/http://www.chefkoch.de:80/rs/s0/spaghettitorte+vom+blech/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_sahne_und_himbeeren_1192658021():
    verify_serp_parsing(
        "https://web.archive.org/web/20071017215341id_/http://www.chefkoch.de:80/rs/s0/,sahne+und+himbeeren/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_spinat_in_1220295440():
    verify_serp_parsing(
        "https://web.archive.org/web/20080901185720id_/http://www.chefkoch.de:80/rs/s0/spinat+in/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_omas_blechkuchen_1355822404():
    verify_serp_parsing(
        "https://web.archive.org/web/20121218092004id_/http://www.chefkoch.de/rs/s0/%2C+omas+blechkuchen/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_spargel_geschlt_1278411144():
    verify_serp_parsing(
        "https://web.archive.org/web/20100706101224id_/http://www.chefkoch.de:80/rs/s0/spargel+gesch%E4lt/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_eierschwammerl_rahmsauce_1449833431():
    verify_serp_parsing(
        "https://web.archive.org/web/20151211113031id_/http://www.chefkoch.de/rs/s0/eierschwammerl+rahmsauce/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_35_backen_1351851992():
    verify_serp_parsing(
        "https://web.archive.org/web/20121102102632id_/http://www.chefkoch.de:80/rs/s0/%2C35+backen/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_eierschwammerl_und_gehacktes_1315110709():
    verify_serp_parsing(
        "https://web.archive.org/web/20110904043149id_/http://www.chefkoch.de/rs/s0/eierschwammerl+und+gehacktes/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_thermomix_gefllten_1390802313():
    verify_serp_parsing(
        "https://web.archive.org/web/20140127055833id_/http://www.chefkoch.de:80/rs/s0/thermomix+gef%FCllten/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_eierlikr_kirschkuchen_1243942587():
    verify_serp_parsing(
        "https://web.archive.org/web/20090602113627id_/http://www.chefkoch.de:80/rs/s0/eierlik%F6r+kirschkuchen/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_syrische_pasta_1466000049():
    verify_serp_parsing(
        "https://web.archive.org/web/20160615141409id_/http://www.chefkoch.de:80/rs/s0/syrische+pasta/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_speckbohnen_mit_kartoffeln_1352170361():
    verify_serp_parsing(
        "https://web.archive.org/web/20121106025241id_/http://www.chefkoch.de:80/rs/s0/,+speckbohnen+mit+kartoffeln/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_spargel_wei_1194284442():
    verify_serp_parsing(
        "https://web.archive.org/web/20071105174042id_/http://www.chefkoch.de:80/rs/s0/spargel%2Cwei%DF/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_tempura_1213419780():
    verify_serp_parsing(
        "https://web.archive.org/web/20080614050300id_/http://www.chefkoch.de:80/rs/s0/tempura%2A/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_suppen_oder_eintpfe_1256106491():
    verify_serp_parsing(
        "https://web.archive.org/web/20091021062811id_/http://www.chefkoch.de:80/rs/s0/suppen+oder+eint%F6pfe/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_eifreier_hackbraten_1356156512():
    verify_serp_parsing(
        "https://web.archive.org/web/20121222060832id_/http://www.chefkoch.de/rs/s0/eifreier+hackbraten/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_kseschnitzel_kse_1353053392():
    verify_serp_parsing(
        "https://web.archive.org/web/20121116080952id_/http://www.chefkoch.de:80/rs/s0/%2Ck%E4seschnitzel+k%E4se/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_eierlikr_mit_kirsch_1375310772():
    verify_serp_parsing(
        "https://web.archive.org/web/20130731224612id_/http://www.chefkoch.de:80/rs/s0/eierlik%F6r+mit+kirsch/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_thai_curry_1246123954():
    verify_serp_parsing(
        "https://web.archive.org/web/20090627173234id_/http://www.chefkoch.de:80/rs/s0/thai-+curry/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_eierflaumsuppe_1249321209():
    verify_serp_parsing(
        "https://web.archive.org/web/20090803174009id_/http://www.chefkoch.de:80/rs/s0/eierflaumsuppe/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_tatar_steak_1266004316():
    verify_serp_parsing(
        "https://web.archive.org/web/20100212195156id_/http://www.chefkoch.de:80/rs/s0/tatar+steak/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_nudelsalat_mit_ei_1330099391():
    verify_serp_parsing(
        "https://web.archive.org/web/20120224160311id_/http://www.chefkoch.de:80/rs/s0/%2Cnudelsalat+mit+ei/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_spaghettie_mit_garnelen_1206750318():
    verify_serp_parsing(
        "https://web.archive.org/web/20080329002518id_/http://www.chefkoch.de:80/rs/s0/spaghettie+mit+garnelen/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_speisestrke_sahne_1232351646():
    verify_serp_parsing(
        "https://web.archive.org/web/20090119075406id_/http://www.chefkoch.de:80/rs/s0/speisest%E4rke+sahne/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_eierlikr_nachspeise_1255758312():
    verify_serp_parsing(
        "https://web.archive.org/web/20091017054512id_/http://www.chefkoch.de:80/rs/s0/eierlik%F6r+nachspeise/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_roulade_braten_1355445937():
    verify_serp_parsing(
        "https://web.archive.org/web/20121214004537id_/http://www.chefkoch.de:80/rs/s0/%2Croulade+braten/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_spaghetti_hhnchen_1192740442():
    verify_serp_parsing(
        "https://web.archive.org/web/20071018204722id_/http://www.chefkoch.de:80/rs/s0/spaghetti+h%E4hnchen/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_kohlroulade_gemse_1328779105():
    verify_serp_parsing(
        "https://web.archive.org/web/20120209091825id_/http://www.chefkoch.de/rs/s0/%2Ckohlroulade+gem%FCse/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_sushi_mit_normalem_reis_1470947014():
    verify_serp_parsing(
        "https://web.archive.org/web/20160811202334id_/http://www.chefkoch.de:80/rs/s0/sushi+mit+normalem+reis/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_tabouleh_rosinen_1382360347():
    verify_serp_parsing(
        "https://web.archive.org/web/20131021125907id_/http://www.chefkoch.de:80/rs/s0/tabouleh+-rosinen/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_kirsch_1305195838():
    verify_serp_parsing(
        "https://web.archive.org/web/20110512102358id_/http://www.chefkoch.de:80/rs/s0/%2C+kirsch/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_speck_zucchini_eier_sahne_1222747904():
    verify_serp_parsing(
        "https://web.archive.org/web/20080930041144id_/http://www.chefkoch.de:80/rs/s0/speck+zucchini+eier+sahne/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_spaghettoni_1206569039():
    verify_serp_parsing(
        "https://web.archive.org/web/20080326220359id_/http://www.chefkoch.de:80/rs/s0/spaghettoni/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_spaghetti_mit_gemsesauce_1190132272():
    verify_serp_parsing(
        "https://web.archive.org/web/20070918161752id_/http://www.chefkoch.de:80/rs/s0/spaghetti+mit+gem%FCsesauce/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_spargel_risotto_mit_garnelen_1471699836():
    verify_serp_parsing(
        "https://web.archive.org/web/20160820133036id_/http://www.chefkoch.de/rs/s0/spargel+risotto+mit+garnelen/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_tupperware_hefe_1356254719():
    verify_serp_parsing(
        "https://web.archive.org/web/20121223092519id_/http://www.chefkoch.de/rs/s0/%2C+tupperware+hefe/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_eier_milch_kse_kartoffeln_1318228714():
    verify_serp_parsing(
        "https://web.archive.org/web/20111010063834id_/http://www.chefkoch.de:80/rs/s0/eier%2C+milch%2C+k%E4se%2C+kartoffeln/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_speck_n_dicken_1370169101():
    verify_serp_parsing(
        "https://web.archive.org/web/20130602103141id_/http://www.chefkoch.de/rs/s0/speck+n+dicken/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_eier_parmesan_spinat_sahne_1206623203():
    verify_serp_parsing(
        "https://web.archive.org/web/20080327130643id_/http://www.chefkoch.de:80/rs/s0/eier+parmesan+spinat+sahne/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_eierlikr_gugelhupf_1203899612():
    verify_serp_parsing(
        "https://web.archive.org/web/20080225003332id_/http://www.chefkoch.de:80/rs/s0/eierlik%F6r+gugelhupf%2C/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_thai_curry_einfach_1420408232():
    verify_serp_parsing(
        "https://web.archive.org/web/20150104215032id_/http://www.chefkoch.de:80/rs/s0/thai+curry+einfach/Rezepte.html",
        "chefkoch",
    )


def test_parse_query_chefkoch_streuselkuchen_aus_mrbeteig_1299585024():
    verify_serp_parsing(
        "https://web.archive.org/web/20110308115024id_/http://www.chefkoch.de:80/rs/s0/%2Cstreuselkuchen+aus+m%FCrbeteig/Rezepte.html",
        "chefkoch",
    )
