# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_360_an_jian_diao_cha_bi_lu_1576497545():
    verify_serp_parsing(
        "https://web.archive.org/web/20191216115905id_/https://www.so.com/s?q=%E6%A1%88%E4%BB%B6%E8%B0%83%E6%9F%A5%E7%AC%94%E5%BD%95&src=related_2.6&psid=836a2b7f45bb7fe2b7bcbe6bbe47b867&nlpv=zzzc_base_2",
        "360",
    )


def test_parse_query_360_chen_teng_tan_han_han_mei_ren_jie_ji_1577810108():
    verify_serp_parsing(
        "https://web.archive.org/web/20191231163508id_/https://www.so.com/s?ie=utf-8&src=know_side_nlp_sohot_online&q=%E6%B2%88%E8%85%BE%E8%B0%88%E9%9F%A9%E5%AF%92%E6%B2%A1%E4%BA%BA%E6%8E%A5%E6%9C%BA&ob_ext=%7B%22rsv_cq%22%3A%22%5Cu514d%5Cu8d39vpn%22%2C%22rt%22%3A%22%5Cu5b9e%5Cu65f6%5Cu70ed%5Cu641c%22%2C%22rclken%22%3Anull%7D",
        "360",
    )


def test_parse_query_360_jin_ji_che_hui_1576637402():
    verify_serp_parsing(
        "https://web.archive.org/web/20191218025002id_/https://www.so.com/s?q=%E7%B4%A7%E6%80%A5%E6%92%A4%E5%9B%9E&src=webcache",
        "360",
    )


def test_parse_query_360_shi_jie_zui_ai_de_ren_qu_shi_1579483438():
    verify_serp_parsing(
        "https://web.archive.org/web/20200120012358id_/https://www.so.com/s?ie=utf-8&src=know_side_nlp_sohot_online&q=%E4%B8%96%E7%95%8C%E6%9C%80%E7%9F%AE%E7%9A%84%E4%BA%BA%E5%8E%BB%E4%B8%96&ob_ext=%7B%22rsv_cq%22%3A%22openeuler%22%2C%22rt%22%3A%22%5Cu5b9e%5Cu65f6%5Cu70ed%5Cu641c%22%2C%22rclken%22%3Anull%7D",
        "360",
    )


def test_parse_query_360_21tian_jian_fei_fa_1653652529():
    verify_serp_parsing(
        "https://web.archive.org/web/20220527115529id_/https://www.so.com/s?src=lm&ls=s4b0c48ca9b&q=21%E5%A4%A9%E5%87%8F%E8%82%A5%E6%B3%95&lmsid=af298c70a1d01987&lm_extend=ctype%3A20%7Clmbid%3A200%7Cjt%3A2%7Cmaxbid%3A%7Csadspace%3A%7Cadid%3A3444654665",
        "360",
    )


def test_parse_query_360_site_chaxun_biz_1551742698():
    verify_serp_parsing(
        "https://web.archive.org/web/20190304233818id_/https://www.so.com/s?q=site:chaxun.biz",
        "360",
    )


def test_parse_query_360_si_chuan_fa_sheng_6_8ji_di_zhen_1662384982():
    verify_serp_parsing(
        "https://web.archive.org/web/20220905133622id_/https://www.so.com/s?q=%E5%9B%9B%E5%B7%9D%E5%8F%91%E7%94%9F6.8%E7%BA%A7%E5%9C%B0%E9%9C%87&src=bkrc&srcg=&stat_source=sshot",
        "360",
    )


def test_parse_query_360_hui_ji_pei_xun_1579668897():
    verify_serp_parsing(
        "https://web.archive.org/web/20200122045457id_/https://www.so.com/s?src=lm&ls=s521c48db9a&q=%E4%BC%9A%E8%AE%A1%E5%9F%B9%E8%AE%AD&lmsid=59a53f2a01747c88&lm_extend=ctype%3A4%7Clmbid%3A20%2C2%2C37%2C30%2C64%2C74%2C7%2C93%2C101%2C110%2C500%7Cjt%3A2%7Cmaxbid%3A%7Csadspace%3A",
        "360",
    )


def test_parse_query_360_site_chaxun_biz_1550161171():
    verify_serp_parsing(
        "https://web.archive.org/web/20190214161931id_/https://www.so.com/s?q=site:chaxun.biz",
        "360",
    )


def test_parse_query_360_mao_bu_yi_xiao_chou_chao_xi_1576791478():
    verify_serp_parsing(
        "https://web.archive.org/web/20191219213758id_/https://www.so.com/s?q=%E6%AF%9B%E4%B8%8D%E6%98%93%E6%B6%88%E6%84%81%E6%8A%84%E8%A2%AD&src=related_2.6&psid=ce3a7e94b02d7f56b85d23614a2be0ae&nlpv=mobile_cooccur_v1",
        "360",
    )


def test_parse_query_360_mei_guo_qian_zheng_1579954288():
    verify_serp_parsing(
        "https://web.archive.org/web/20200125121128id_/https://www.so.com/s?src=lm&ls=s521c48db9a&q=%E7%BE%8E%E5%9B%BD%E7%AD%BE%E8%AF%81&lmsid=30e88c9397a90e32&lm_extend=ctype%3A4%7Clmbid%3A203%7Cjt%3A2%7Cmaxbid%3A%7Csadspace%3A",
        "360",
    )


def test_parse_query_360_duo_jia_ju_chang_qu_xiao_yan_chu_1579663841():
    verify_serp_parsing(
        "https://web.archive.org/web/20200122033041id_/https://www.so.com/s?ie=utf-8&src=know_side_nlp_sohot_online&q=%E5%A4%9A%E5%AE%B6%E5%89%A7%E5%9C%BA%E5%8F%96%E6%B6%88%E6%BC%94%E5%87%BA&ob_ext=%7B%22rsv_cq%22%3A%22%5Cu8003%5Cu7814%5Cu4f5c%5Cu5f0a%22%2C%22rt%22%3A%22%5Cu5b9e%5Cu65f6%5Cu70ed%5Cu641c%22%2C%22rclken%22%3Anull%7D",
        "360",
    )


def test_parse_query_360_wu_xiu_bo_yang_kun_ju_hui_hai_ge_1577858222():
    verify_serp_parsing(
        "https://web.archive.org/web/20200101055702id_/https://www.so.com/s?ie=utf-8&src=know_side_nlp_sohot_online&q=%E5%90%B4%E7%A7%80%E6%B3%A2%E6%9D%A8%E5%9D%A4%E8%81%9A%E4%BC%9A%E5%97%A8%E6%AD%8C&ob_ext=%7B%22rsv_cq%22%3A%22%5Cu4e2a%5Cu4eba%5Cu6570%5Cu636e%5Cu6cc4%5Cu9732%22%2C%22rt%22%3A%22%5Cu5b9e%5Cu65f6%5Cu70ed%5Cu641c%22%2C%22rclken%22%3Anull%7D",
        "360",
    )


def test_parse_query_360_tao_bao_ru_he_che_hui_ping_jie_1576604187():
    verify_serp_parsing(
        "https://web.archive.org/web/20191217173627id_/https://www.so.com/s?q=%E6%B7%98%E5%AE%9D%E5%A6%82%E4%BD%95%E6%92%A4%E5%9B%9E%E8%AF%84%E4%BB%B7&psid=ddf2765c1c51375b28acdb33c3767871&nlpv=zzzc_base_1&src=pdr_guide_2.6",
        "360",
    )


def test_parse_query_360_site_chaxun_biz_1550145271():
    verify_serp_parsing(
        "https://web.archive.org/web/20190214115431id_/https://www.so.com/s?q=site:chaxun.biz",
        "360",
    )


def test_parse_query_360_ju_min_jia_zhong_fei_jin_bian_fu_1585788499():
    verify_serp_parsing(
        "https://web.archive.org/web/20200402004819id_/https://www.so.com/s?q=%E5%B1%85%E6%B0%91%E5%AE%B6%E4%B8%AD%E9%A3%9E%E8%BF%9B%E8%9D%99%E8%9D%A0&src=know_side_nlp_sohot&tn=news",
        "360",
    )


def test_parse_query_360_site_eng_kaz_enacademic_com_1581787441():
    verify_serp_parsing(
        "https://web.archive.org/web/20200215172401id_/https://www.so.com/s?q=site%3Aeng_kaz.enacademic.com",
        "360",
    )


def test_parse_query_360_niu_jie_5hao_1576819311():
    verify_serp_parsing(
        "https://web.archive.org/web/20191220052151id_/https://www.so.com/s?q=%E7%89%9B%E6%9D%B05%E5%8F%B7&src=related_2.6&psid=7023274fd3a925bfe6b5bc6c27debf13&nlpv=zzzc_base_2",
        "360",
    )


def test_parse_query_360_zhang_bo_zhi_bei_gou_yao_shang_1661090641():
    verify_serp_parsing(
        "https://web.archive.org/web/20220821140401id_/https://www.so.com/s?ie=utf-8&src=know_side_nlp_sohot_online_clk&q=%E5%BC%A0%E6%9F%8F%E8%8A%9D%E8%A2%AB%E7%8B%97%E5%92%AC%E4%BC%A4&ob_ext=%7B%22rsv_cq%22%3A%22%5Cu6bdb%5Cu4e0d%5Cu6613%22%2C%22rt%22%3A%22%5Cu5b9e%5Cu65f6%5Cu70ed%5Cu641c%22%2C%22rclken%22%3Anull%7D",
        "360",
    )


def test_parse_query_360_lu_xing_she_tuan_dui_you_zan_ting_1580014331():
    verify_serp_parsing(
        "https://web.archive.org/web/20200126045211id_/https://www.so.com/s?ie=utf-8&q=%E6%97%85%E8%A1%8C%E7%A4%BE%E5%9B%A2%E9%98%9F%E6%B8%B8%E6%9A%82%E5%81%9C&src=no_result_hot",
        "360",
    )
