# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_stackoverflow_objective_c_1354546520():
    verify_serp_parsing(
        "https://web.archive.org/web/20121203145520id_/http://stackoverflow.com/questions/tagged/objective-c",
        "stackoverflow",
    )


def test_parse_query_stackoverflow_scala_1355718931():
    verify_serp_parsing(
        "https://web.archive.org/web/20121217043531id_/http://stackoverflow.com/questions/tagged/scala",
        "stackoverflow",
    )


def test_parse_query_stackoverflow_remote_execution_1645839151():
    verify_serp_parsing(
        "https://web.archive.org/web/20220226013231id_/https://stackoverflow.com/questions/tagged/remote-execution",
        "stackoverflow",
    )


def test_parse_query_stackoverflow_text_mining_1522322354():
    verify_serp_parsing(
        "https://web.archive.org/web/20180329111914id_/https://stackoverflow.com/questions/tagged/text-mining",
        "stackoverflow",
    )


def test_parse_query_stackoverflow_vue_js_php_1647710017():
    verify_serp_parsing(
        "https://web.archive.org/web/20220319171337id_/https://stackoverflow.com/questions/tagged/vue.js+php",
        "stackoverflow",
    )


def test_parse_query_stackoverflow_ruby_on_rails_plugins_1613971498():
    verify_serp_parsing(
        "https://web.archive.org/web/20210222052458id_/https://stackoverflow.com/questions/tagged/ruby-on-rails-plugins",
        "stackoverflow",
    )


def test_parse_query_stackoverflow_ruby_1_9_3_heroku_1398351399():
    verify_serp_parsing(
        "https://web.archive.org/web/20140424145639id_/http://stackoverflow.com/questions/tagged/ruby-1.9.3+heroku",
        "stackoverflow",
    )


def test_parse_query_stackoverflow_fonts_swing_jtextpane_1412916125():
    verify_serp_parsing(
        "https://web.archive.org/web/20141010044205id_/http://stackoverflow.com/questions/tagged/fonts+swing+jtextpane",
        "stackoverflow",
    )


def test_parse_query_stackoverflow_xampp_java_1547581001():
    verify_serp_parsing(
        "https://web.archive.org/web/20190115193641id_/https://stackoverflow.com/questions/tagged/xampp+java",
        "stackoverflow",
    )


def test_parse_query_stackoverflow_numpy_einsum_1516773912():
    verify_serp_parsing(
        "https://web.archive.org/web/20180124060512id_/https://stackoverflow.com/questions/tagged/numpy-einsum",
        "stackoverflow",
    )
