# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_twitch_juliversal_1629750531():
    verify_serp_parsing(
        "https://web.archive.org/web/20210823202851id_/https://www.twitch.tv/search?term=juliversal",
        "twitch",
    )


def test_parse_query_twitch_simplevar_1662753027():
    verify_serp_parsing(
        "https://web.archive.org/web/20220909195027id_/https://www.twitch.tv/search?term=%09%20SimpleVar",
        "twitch",
    )


def test_parse_query_twitch_cpentagon_1640060311():
    verify_serp_parsing(
        "https://web.archive.org/web/20211221041831id_/https://www.twitch.tv/search?term=CPentagon",
        "twitch",
    )


def test_parse_query_twitch_rubberboy2001_1661349876():
    verify_serp_parsing(
        "https://web.archive.org/web/20220824140436id_/https://www.twitch.tv/search?term=rubberboy2001",
        "twitch",
    )


def test_parse_query_twitch_central_fluminense_1630540704():
    verify_serp_parsing(
        "https://web.archive.org/web/20210901235824id_/https://www.twitch.tv/search?term=central%20fluminense",
        "twitch",
    )


def test_parse_query_twitch_xxlillythefallenangelneko_1638019769():
    verify_serp_parsing(
        "https://web.archive.org/web/20211127132929id_/https://www.twitch.tv/search?term=xxlillythefallenangelneko",
        "twitch",
    )


def test_parse_query_twitch_a_plague_tale_innocence_1638358324():
    verify_serp_parsing(
        "https://web.archive.org/web/20211201113204id_/https://www.twitch.tv/search?term=A%20Plague%20Tale%3A%20Innocence&type=categories&ref=NEXARDA",
        "twitch",
    )
