# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_twitter_rabble_ca_lang_ar_1442999332():
    verify_serp_parsing(
        "https://web.archive.org/web/20150923090852id_/https://mobile.twitter.com/search?vertical=default&near=me&q=rabble.ca%3Flang%3Dar&locale=ro",
        "twitter",
    )


def test_parse_query_twitter_rabble_ca_lang_fr_lang_id_1443046297():
    verify_serp_parsing(
        "https://web.archive.org/web/20150923221137id_/https://twitter.com/search?q=rabble.ca%3Flang%3Dfr%3Flang%3Did&f=videos&vertical=default&lang=sv",
        "twitter",
    )


def test_parse_query_twitter_lauramajor_1652839406():
    verify_serp_parsing(
        "https://web.archive.org/web/20220518020326id_/https://twitter.com/search?q=lauramajor&lang=no",
        "twitter",
    )


def test_parse_query_twitter_ecotourism_1557315321():
    verify_serp_parsing(
        "https://web.archive.org/web/20190508113521id_/https://twitter.com/search?q=%23Ecotourism",
        "twitter",
    )


def test_parse_query_twitter_freemariabutina_1563062689():
    verify_serp_parsing(
        "https://web.archive.org/web/20190714000449id_/https://twitter.com/search?q=%23FreeMariaButina&l=is&vertical=default&lang=mr",
        "twitter",
    )


def test_parse_query_twitter_http_shop_pre_com_corona02_p_409033_1648579256():
    verify_serp_parsing(
        "https://web.archive.org/web/20220329184056id_/https://mobile.twitter.com/search?q=http%3A%2F%2Fshop-pre.com%2Fcorona02%2F%3Fp%3D409033&lang=kn",
        "twitter",
    )


def test_parse_query_twitter_clubs_lang_sr_1591413117():
    verify_serp_parsing(
        "https://web.archive.org/web/20200606031157id_/https://twitter.com/search?q=clubs%3Flang%3Dsr&lang=en",
        "twitter",
    )


def test_parse_query_twitter_freemariabutina_1555124003():
    verify_serp_parsing(
        "https://web.archive.org/web/20190413025323id_/https://mobile.twitter.com/search?vertical=default&locale=es&q=%23FreeMariaButina&l=ja",
        "twitter",
    )


def test_parse_query_twitter_freemariabutina_1562498575():
    verify_serp_parsing(
        "https://web.archive.org/web/20190707112255id_/https://mobile.twitter.com/search?vertical=default&locale=id&q=%23FreeMariaButina&f=tweets",
        "twitter",
    )


def test_parse_query_twitter_campaigns_1481768285():
    verify_serp_parsing(
        "https://web.archive.org/web/20161215021805id_/https://twitter.com/search?q=campaigns&lang=ko",
        "twitter",
    )
