# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_pornhub_kardashian_1232246712():
    verify_serp_parsing(
        "https://web.archive.org/web/20090118024512id_/http://www.pornhub.com:80/video/search?search=kardashian&p=&c=32",
        "pornhub",
    )


def test_parse_query_pornhub_org_1219567054():
    verify_serp_parsing(
        "https://web.archive.org/web/20080824083734id_/http://www.pornhub.com:80/video/search?search=org",
        "pornhub",
    )


def test_parse_query_pornhub_mini_skirt_1257166127():
    verify_serp_parsing(
        "https://web.archive.org/web/20091102124847id_/http://www.pornhub.com:80/video/search?search=mini+skirt&c=37",
        "pornhub",
    )


def test_parse_query_pornhub_full_porno_films_1633148146():
    verify_serp_parsing(
        "https://web.archive.org/web/20211002041546id_/https://www.pornhub.com/video/search?search=full+porno+films",
        "pornhub",
    )


def test_parse_query_pornhub_brazilian_carnival_1378864891():
    verify_serp_parsing(
        "https://web.archive.org/web/20130911020131id_/http://www.pornhub.com:80/video/search?search=brazilian+carnival",
        "pornhub",
    )


def test_parse_query_pornhub_cfnm2_1271707129():
    verify_serp_parsing(
        "https://web.archive.org/web/20100419195849id_/http://www.pornhub.com:80/video/search?search=CFNM2&x=0&y=0",
        "pornhub",
    )


def test_parse_query_pornhub_12_1565436858():
    verify_serp_parsing(
        "https://web.archive.org/web/20190810113418id_/https://www.pornhub.com/video/search?search=12&o=mv",
        "pornhub",
    )


def test_parse_query_pornhub_roxy_reynolds_1222496976():
    verify_serp_parsing(
        "https://web.archive.org/web/20080927062936id_/http://www.pornhub.com:80/video/search?search=Roxy+Reynolds&c=1",
        "pornhub",
    )


def test_parse_query_pornhub_teen_facial_1237526884():
    verify_serp_parsing(
        "https://web.archive.org/web/20090320052804id_/http://www.pornhub.com:80/video/search?search=teen+facial&p=&c=15",
        "pornhub",
    )


def test_parse_query_pornhub_stripping_1627962626():
    verify_serp_parsing(
        "https://web.archive.org/web/20210803035026id_/https://www.pornhub.com/video/search?search=stripping%5D",
        "pornhub",
    )
