# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_google_taikoo_hui_mandarin_oriental_hotel_guangzhou_1652086766():
    verify_serp_parsing(
        "https://web.archive.org/web/20220509085926id_/https://www.google.com/search?q=Taikoo+Hui+Mandarin+Oriental+Hotel+Guangzhou",
        "google",
    )


def test_parse_query_google_finance_1540158323():
    verify_serp_parsing(
        "https://web.archive.org/web/20181021214523id_/http://www.google.co.uk/search?q=finance&gbv=1&sei=jw_NW8voLJWv0PEPld2DuA8",
        "google",
    )


def test_parse_query_google_hawaii_part_ii_lyrics_1633318830():
    verify_serp_parsing(
        "https://web.archive.org/web/20211004034030id_/https://www.google.com/search?q=Hawaii+part+ii+lyrics&sa=X&ved=2ahUKEwjA74_v6arzAhVTwZ4KHfAcBCAQ1QJ6BAgFEAw",
        "google",
    )


def test_parse_query_google_attack_on_titan_season_3_part_2_1556408967():
    verify_serp_parsing(
        "https://web.archive.org/web/20190427234927id_/https://www.google.com/search?q=attack+on+titan+season+3+part+2&rlz=1C1CHBF_en-GBGB760GB760&oq=attac&aqs=chrome.0.69i59j0l2j69i65l3.1486j0j4&sourceid=chrome&ie=UTF-8",
        "google",
    )


def test_parse_query_google_win10_iso_xia_zai_1577717811():
    verify_serp_parsing(
        "https://web.archive.org/web/20191230145651id_/https://www.google.com/search?q=win10+iso+%E4%B8%8B%E8%BD%BD&tbm=nws&source=lnt&tbs=qdr%3Ay&sa=X&ved=0ahUKEwjurrCb3t3mAhXPjp4KHT3MDxg4FBCnBQgf",
        "google",
    )


def test_parse_query_google_243_1628713922():
    verify_serp_parsing(
        "https://web.archive.org/web/20210811203202id_/https://www.google.com/search?q=243",
        "google",
    )


def test_parse_query_google_does_steve_has_a_beard_1601705030():
    verify_serp_parsing(
        "https://web.archive.org/web/20201003060350id_/https://www.google.com/search?q=does+steve+has+a+beard&oq=does+steve+has+a+beard&aqs=chrome..69i57j0i22i30l3.6767j0j4&sourceid=chrome&ie=UTF-8",
        "google",
    )


def test_parse_query_google_why_is_one_foot_slightly_larger_than_the_other_one_1605140430():
    verify_serp_parsing(
        "https://web.archive.org/web/20201112002030id_/https://www.google.com/search?q=Why%20is%20one%20foot%20slightly%20larger%20than%20the%20other%20one%3F",
        "google",
    )


def test_parse_query_google_zombie_apocalypse_1565114134():
    verify_serp_parsing(
        "https://web.archive.org/web/20190806175534id_/https://www.google.com/search?q=zombie+apocalypse&rlz=1C1GCEA_enGB797GB797&source=lnms&tbm=vid&sa=X&ved=0ahUKEwjo4aahg-_jAhUPTcAKHa1NCZ4Q_AUIEigC",
        "google",
    )


def test_parse_query_google_scholar_w_fan_j_li_s_ma_n_tang_and_w_yu_april_2012_towards_certain_fixes_with_editing_rules_and_master_data_the_vldb_journal_21_2_213_238_297_10_1007_s00778_011_0253_7_1614165399():
    verify_serp_parsing(
        "https://web.archive.org/web/20210224111639id_/https://scholar.google.com/scholar?hl=en&q=W.+Fan%2C+J.+Li%2C+S.+Ma%2C+N.+Tang%2C+and+W.+Yu.+April+2012.+Towards+certain+fixes+with+editing+rules+and+master+data.+The+VLDB+Journal%2C+21(2)%3A+213--238.+297+10.1007%2Fs00778-011-0253-7+",
        "google-scholar",
    )


def test_parse_query_google_susan_boyle_make_me_a_channel_of_your_peace_1607791072():
    verify_serp_parsing(
        "https://web.archive.org/web/20201212163752id_/http://www.google.ca/search?sa=X&q=Susan+Boyle+Make+Me+a+Channel+of+Your+Peace&stick=H4sIAAAAAAAAAIVUPWjUYBjOnbZe0xZ6qaDcIPF0qBW9Sy4_PZcWi0KhpdLe0ikkX_Ill3z58vOld0lEBOdOgjoKTg4dnRRECg4WcXAQXKy4OSm6dNHaWvOzmSHkyfu8z_t87_vy1UaaEy2zxZG2SAIIZX7cN1RgsMTDJtmtZLFIGRD_HwxEW9NEIhcQKAArOVmS-MDVdyuTR5ADHXdIBibIsJMocafLOxmGURpwsaJkWI_dQISWmWFbsNwUDt2imk3ECGZhLbHjMLLNwipydDvM1QU_4FwgFGHX9rtcFragrQ1DG5SyzVTUSmxFCkvarm5CkpceSG2lnfo5ngNSYA7S0sn9FEVR7oWXdEBwuzhJalkcKtQHWBasPJvHlmaRoi8waQucmxbZsQbNuCyGO7hoC4qDLhDzsBXITsqVBipBvhjZ8ewLGMaWGJR8CxiLYo6tyA263FyGTc4M7O4QlfghAFJpe0iSup2ScRzBbj5fTg-QFJS7JGNRlsrLFiOrEBuKtpLPACqQxwF2CrbAoaPtyNk8GQqlJoFYz5dDk2V-btDh85bLStJ1dLdkXI9BqXTqwJB8qbyujk993f803XhRvb_95kPlWZWeWvY8YqBkzUBqZOg9j7lIj97AUT9KmAY90ai13FZbEm1_hmrQdI6YrQo9vm5EPW_F0_swYe4wt-mxFcPVjJCsQqZH04seQgaI-h5mbtLNxrkWyH-0QgN4od7HpgLQJokOcw7lWfo_nObptb8GhBDB4y9ZgNG16ky16fDK8_cP341u1AdvDw4m_aWFxqVZhj61RJY9oKL6o89XXn38_W1-dpqu9dTYw56b1Km_z_f55vmxCz-Sx1vbe_P1n7MUtdc_s3D2BEvNUNzq_q-7Ow-uLsxS914-3Rk9WatMURNPRi6vbxIVs9e9BBnsiuocvgxWZRctFWMDsR5kN7zNkL11dCP9AYhSBnypBAAA&ved=2ahUKEwixvarn35TtAhXC3J4KHZIqBmYQ-BZ6BAgSEEA",
        "google",
    )


def test_parse_query_google_scholar_muhammed_rashid_1656890873():
    verify_serp_parsing(
        "https://web.archive.org/web/20220703232753id_/https://scholar.google.com/scholar?q=Muhammed+Rashid",
        "google-scholar",
    )


def test_parse_query_google_scholar_a_tumeo_m_branca_l_camerini_a_dual_priority_realtime_multiprocessor_system_on_fpga_for_automotive_ap_1614181186():
    verify_serp_parsing(
        "https://web.archive.org/web/20210224153946id_/https://scholar.google.com/scholar?hl=en&q=A.+Tumeo%2C+M.+Branca%2C+L.+Camerini%2C+%22A+Dual-Priority+RealTime+Multiprocessor+System+on+FPGA+for+Automotive+Applications%22%2C+Design%2C+Automation+and+Test+in+Europe+(DATE)+2008%2C+pages+1039--1044.+10.1145%2F1403375.1403625+",
        "google-scholar",
    )


def test_parse_query_google_hola_games_1552338270():
    verify_serp_parsing(
        "https://web.archive.org/web/20190311210430id_/https://www.google.com/search?q=Hola+Games&stick=H4sIAAAAAAAAAONgFuLSz9U3KE7PKCk2UOLVT9c3NEw3M801Kykr1lLOTrbSTy5L10_Ozy0oLUktii_LTEnNT0_MTbUqBrLKEyuLHzHGcQu8_HFPWCp00pqT1xj9uYjRJaTBxeaaV5JZUikkx8UnheQGDQYpHi4kPs8iVmGQ1mKFnMzsVIWSjFSFovz8XACNNlkjuQAAAA&sa=X&ved=0ahUKEwi839n-i_vgAhUGMt8KHUS9AjgQ-BYIUA",
        "google",
    )


def test_parse_query_google_chi_zhen_nzhong_rong_keteru_1608917828():
    verify_serp_parsing(
        "https://web.archive.org/web/20201225173708id_/https://www.google.co.jp/search?q=%E6%AD%AF+%E7%9C%9F%E3%82%93%E4%B8%AD%E6%BA%B6%E3%81%91%E3%81%A6%E3%82%8B&ie=UTF-8&oe=UTF-8&hl=ja-jp&client=safari",
        "google",
    )


def test_parse_query_google_bill_easley_sophisticated_prelude_1626498182():
    verify_serp_parsing(
        "https://web.archive.org/web/20210717050302id_/https://www.google.com/search?q=bill+easley+sophisticated+prelude&stick=H4sIAAAAAAAAAONgFuLSz9U3MM4wNSspUeLVT9c3NMwyM8jJMCvI0xLLTrbSzy0tzkzWTywqySwusSrOz0svXsSqmJSZk6OQmlick1qpUJxfkAGUy0xOLElNUSgoSs0pTUkFAB_nXk9ZAAAA&sa=X&ved=2ahUKEwjr3cn27-PxAhUTHzQIHXLBBTAQri4wCnoECAoQVA",
        "google",
    )


def test_parse_query_google_atalanta_bergamasca_calcio_wikipedia_1643703998():
    verify_serp_parsing(
        "https://web.archive.org/web/20220201082638id_/https://www.google.com/search?q=%22Atalanta+Bergamasca+Calcio%22+-wikipedia&source=lnms&tbm=vid&sa=X&ved=0ahUKEwirydi73J_1AhVCl2oFHdPMDeUQ_AUICygE",
        "google",
    )


def test_parse_query_google_orlando_bedoya_site_wikipedia_org_site_wikimedia_org_1629326434():
    verify_serp_parsing(
        "https://web.archive.org/web/20210818224034id_/https://www.google.com/search?safe=off&tbs=sur:fmc&tbm=isch&q=%22Orlando+bedoya%22+-site:wikipedia.org+-site:wikimedia.org",
        "google",
    )


def test_parse_query_google_flop_thumbs_up_1568839345():
    verify_serp_parsing(
        "https://web.archive.org/web/20190918204225id_/https://www.google.com/search?q=flop+thumbs+up&oq=flop+thumbs+up&aqs=chrome..69i57j69i60l2j69i61j69i65l2.3098j0j7&sourceid=chrome&ie=UTF-8",
        "google",
    )


def test_parse_query_google_ocolc_826746_1240020639():
    verify_serp_parsing(
        "https://web.archive.org/web/20090418021039id_/http://www.google.com/search?q=(OCoLC)826746&safe=vss&vss=1&sa=Google+Search",
        "google",
    )


def test_parse_query_google_george_w_summers_1637786317():
    verify_serp_parsing(
        "https://web.archive.org/web/20211124203837id_/https://www.google.com/search?as_eq=wikipedia&q=%22George+W.+Summers%22",
        "google",
    )


def test_parse_query_google_grasshopper_design_pvt_ltd_1640249780():
    verify_serp_parsing(
        "https://web.archive.org/web/20211223085620id_/https://www.google.com/search?as_eq=wikipedia&q=%22Grasshopper+Design+Pvt.+Ltd.%22",
        "google",
    )


def test_parse_query_google_pareques_site_hu_wikipedia_org_1647941362():
    verify_serp_parsing(
        "https://web.archive.org/web/20220322092922id_/https://www.google.com/search?q=%22Pareques%22+site:hu.wikipedia.org",
        "google",
    )


def test_parse_query_google_coneybury_anomaly_wikipedia_1640176109():
    verify_serp_parsing(
        "https://web.archive.org/web/20211222122829id_/https://www.google.com/search?tbs=bks:1&q=%22Coneybury+Anomaly%22+-wikipedia",
        "google",
    )


def test_parse_query_google_laxmikant_pyarelal_1657295550():
    verify_serp_parsing(
        "https://web.archive.org/web/20220708155230id_/https://www.google.com/search?as_eq=wikipedia&q=%22Laxmikant%E2%80%93Pyarelal%22",
        "google",
    )


def test_parse_query_google_kurabayashi_1643815267():
    verify_serp_parsing(
        "https://web.archive.org/web/20220202152107id_/https://www.google.com/search?as_eq=wikipedia&q=%22Kurabayashi%22",
        "google",
    )


def test_parse_query_google_gnosticism_1615175612():
    verify_serp_parsing(
        "https://web.archive.org/web/20210308035332id_/https://www.google.com/search?as_eq=wikipedia&q=%22Gnosticism%22",
        "google",
    )


def test_parse_query_google_fatmira_brecani_1662136538():
    verify_serp_parsing(
        "https://web.archive.org/web/20220902163538id_/https://www.google.com/search?as_eq=wikipedia&q=%22Fatmira+Bre%C3%A7ani%22",
        "google",
    )


def test_parse_query_google_kostiantyn_magaletskyi_1638351261():
    verify_serp_parsing(
        "https://web.archive.org/web/20211201093421id_/https://www.google.com/search?as_eq=wikipedia&q=%22Kostiantyn+Magaletskyi%22",
        "google",
    )


def test_parse_query_google_future_planning_1648480487():
    verify_serp_parsing(
        "https://web.archive.org/web/20220328151447id_/https://www.google.com/search?as_eq=wikipedia&q=%22Future+Planning%22",
        "google",
    )


def test_parse_query_google_list_of_surviving_lockheed_f_104_starfighters_1662745731():
    verify_serp_parsing(
        "https://web.archive.org/web/20220909174851id_/https://www.google.com/search?as_eq=wikipedia&q=%22List+of+surviving+Lockheed+F-104+Starfighters%22",
        "google",
    )


def test_parse_query_google_modern_times_chaplin_watch_online_1662343522():
    verify_serp_parsing(
        "https://web.archive.org/web/20220905020522id_/https://www.google.com.hk/search?q=modern+times+chaplin+watch+online",
        "google",
    )


def test_parse_query_google_lars_brygmann_1633135602():
    verify_serp_parsing(
        "https://web.archive.org/web/20211002004642id_/https://www.google.com/search?as_eq=wikipedia&q=%22Lars+Brygmann%22",
        "google",
    )


def test_parse_query_google_boulevard_records_canada_site_wikipedia_org_site_wikimedia_org_1510135498():
    verify_serp_parsing(
        "https://web.archive.org/web/20171108100458id_/https://www.google.com/search?safe=off&tbm=isch&tbs=sur:fmc&q=%22Boulevard+Records%22+Canada+-site:wikipedia.org+-site:wikimedia.org",
        "google",
    )


def test_parse_query_google_continental_automotive_systems_wikipedia_1651015350():
    verify_serp_parsing(
        "https://web.archive.org/web/20220426232230id_/https://www.google.com/search?tbs=bks:1&q=%22Continental+Automotive+Systems%22+-wikipedia",
        "google",
    )


def test_parse_query_google_bouncing_hero_switch_site_easyallies_com_1633303267():
    verify_serp_parsing(
        "https://web.archive.org/web/20211003232107id_/https://www.google.com/search?q=%22Bouncing%20Hero%22+%22switch%22+site:easyallies.com",
        "google",
    )


def test_parse_query_google_evan_colborne_1647984326():
    verify_serp_parsing(
        "https://web.archive.org/web/20220322212526id_/https://www.google.com/search?q=%22Evan+Colborne%22&rlz=1C1GCEB_enCA943CA943&oq=%22Evan+Colborne%22&aqs=chrome..69i57j0i30.3299j0j7&sourceid=chrome&ie=UTF-8",
        "google",
    )


def test_parse_query_google_lycee_francais_louis_pasteur_de_lagos_1638831028():
    verify_serp_parsing(
        "https://web.archive.org/web/20211206225028id_/https://www.google.com/search?as_eq=wikipedia&q=%22Lyc%C3%A9e+Fran%C3%A7ais+Louis+Pasteur+de+Lagos%22",
        "google",
    )


def test_parse_query_google_compress_tube_wikipedia_1644670761():
    verify_serp_parsing(
        "https://web.archive.org/web/20220212125921id_/https://www.google.com/search?tbs=bks:1&q=%22Compress+Tube%22+-wikipedia",
        "google",
    )


def test_parse_query_google_lige_gardner_1637042221():
    verify_serp_parsing(
        "https://web.archive.org/web/20211116055701id_/https://www.google.com/search?as_eq=wikipedia&q=%22Lige+Gardner%22",
        "google",
    )


def test_parse_query_google_lope_recio_loynaz_1658853508():
    verify_serp_parsing(
        "https://web.archive.org/web/20220726163828id_/https://www.google.com/search?as_eq=wikipedia&q=%22Lope+Recio+Loynaz%22",
        "google",
    )


def test_parse_query_google_bozsa_bence_site_hu_wikipedia_org_1647787452():
    verify_serp_parsing(
        "https://web.archive.org/web/20220320144412id_/https://www.google.com/search?q=%22Bozsa+Bence%22+site:hu.wikipedia.org",
        "google",
    )


def test_parse_query_google_fer_palacio_1631069534():
    verify_serp_parsing(
        "https://web.archive.org/web/20210908025214id_/https://www.google.com/search?as_eq=wikipedia&q=%22Fer+Palacio%22",
        "google",
    )


def test_parse_query_google_green_capital_energy_site_wikipedia_org_site_wikimedia_org_1657756151():
    verify_serp_parsing(
        "https://web.archive.org/web/20220713234911id_/https://www.google.com/search?safe=off&tbs=sur:fmc&tbm=isch&q=%22Green+Capital+Energy%22+-site:wikipedia.org+-site:wikimedia.org&spell=1&sa=X&ved=2ahUKEwie4oTthrz1AhWTHTQIHbsuDQ8QBXoECAAQAQ",
        "google",
    )


def test_parse_query_google_facebuster_1650197554():
    verify_serp_parsing(
        "https://web.archive.org/web/20220417121234id_/https://www.google.com/search?&q=%22Facebuster%22&tbs=bkt:s&tbm=bks",
        "google",
    )


def test_parse_query_google_focusrite_1641240556():
    verify_serp_parsing(
        "https://web.archive.org/web/20220103200916id_/https://www.google.com/search?as_eq=wikipedia&q=%22Focusrite%22",
        "google",
    )


def test_parse_query_google_kolex_1645947964():
    verify_serp_parsing(
        "https://web.archive.org/web/20220227074604id_/https://www.google.com/search?as_eq=wikipedia&q=%22Kolex%22",
        "google",
    )


def test_parse_query_google_list_of_grand_dukes_of_russia_1645733808():
    verify_serp_parsing(
        "https://web.archive.org/web/20220224201648id_/https://www.google.com/search?as_eq=wikipedia&q=%22List+of+grand+dukes+of+Russia%22",
        "google",
    )


def test_parse_query_google_green_wave_106_5_fm_1637281540():
    verify_serp_parsing(
        "https://web.archive.org/web/20211119002540id_/http://www.google.com/search?tbo=p&tbm=bks&q=%22Green+Wave+106.5+FM%22",
        "google",
    )


def test_parse_query_google_front_polisario_khat_al_shahid_1652852892():
    verify_serp_parsing(
        "https://web.archive.org/web/20220518054812id_/https://www.google.com/search?as_eq=wikipedia&q=%22Front+Polisario+Khat+al-Shahid%22",
        "google",
    )


def test_parse_query_google_guntury_1650179158():
    verify_serp_parsing(
        "https://web.archive.org/web/20220417070558id_/https://www.google.com/search?as_eq=wikipedia&q=%22Guntury%22",
        "google",
    )


def test_parse_query_google_film_review_annual_1660769248():
    verify_serp_parsing(
        "https://web.archive.org/web/20220817204728id_/https://www.google.com/search?as_eq=wikipedia&q=%22Film+Review+(annual)%22",
        "google",
    )


def test_parse_query_google_lucas_ruzin_1658326494():
    verify_serp_parsing(
        "https://web.archive.org/web/20220720141454id_/https://www.google.com/search?as_eq=wikipedia&q=%22Lucas+Ruzin%22",
        "google",
    )


def test_parse_query_google_kush_raval_indian_cricketer_site_wikipedia_org_site_wikimedia_org_1649726560():
    verify_serp_parsing(
        "https://web.archive.org/web/20220412012240id_/https://www.google.com/search?safe=off&tbs=sur:fmc&tbm=isch&q=%22Kush+Raval+Indian+Cricketer%22+-site:wikipedia.org+-site:wikimedia.org",
        "google",
    )


def test_parse_query_google_sarah_monfort_wikipedia_1647374906():
    verify_serp_parsing(
        "https://web.archive.org/web/20220315200826id_/https://www.google.com/search?tbs=bks:1&q=%22Sarah+Monfort%22+-wikipedia",
        "google",
    )


def test_parse_query_google_list_of_crossings_of_the_james_river_1662064377():
    verify_serp_parsing(
        "https://web.archive.org/web/20220901203257id_/https://www.google.com/search?as_eq=wikipedia&q=%22List+of+crossings+of+the+James+River%22",
        "google",
    )


def test_parse_query_google_kothuru_assembly_constituency_1631384737():
    verify_serp_parsing(
        "https://web.archive.org/web/20210911182537id_/https://www.google.com/search?as_eq=wikipedia&q=%22Kothuru%22+Assembly+constituency",
        "google",
    )


def test_parse_query_google_can_ju_ying_yu_1560296360():
    verify_serp_parsing(
        "https://web.archive.org/web/20190611233920id_/https://www.google.com/search?safe=active&q=%E9%A4%90%E5%85%B7%E8%8B%B1%E8%AF%AD&sa=X&ved=2ahUKEwjhxJLa5-LiAhWRCXwKHSL2ArUQ1QIoB3oECAoQCA",
        "google",
    )


def test_parse_query_google_leo_de_la_strehaia_1633884656():
    verify_serp_parsing(
        "https://web.archive.org/web/20211010165056id_/https://www.google.com/search?as_eq=wikipedia&q=%22Leo+de+la+Strehaia%22",
        "google",
    )


def test_parse_query_google_conflict_middle_east_wikipedia_1636797028():
    verify_serp_parsing(
        "https://web.archive.org/web/20211113095028id_/https://www.google.com/search?tbs=bks:1&q=%22Conflict:+Middle+East%22+-wikipedia",
        "google",
    )


def test_parse_query_google_diffusion_systems_for_evaluation_of_biomineralization_1618448715():
    verify_serp_parsing(
        "https://web.archive.org/web/20210415010515id_/http://www.google.com/search?hl=en&ie=UTF-8&lr=&num=100&prmd=ivns&q=%22Diffusion+Systems+for+Evaluation+of+Biomineralization&sa=X&safe=off&site=unclesam&source=lnms&tbm=isch&ved=0ahUKEwiN-62-svLZAhXEl-AKHReSCO4Q_AUIBQ",
        "google",
    )


def test_parse_query_google_list_of_cantons_of_france_1634951028():
    verify_serp_parsing(
        "https://web.archive.org/web/20211023010348id_/https://www.google.com/search?as_eq=wikipedia&q=%22List+of+cantons+of+France%22",
        "google",
    )


def test_parse_query_google_scholar_wan_y_menon_s_and_ramaprasad_a_2009_the_paradoxical_nature_of_electronic_decision_aids_on_comparison_1614187144():
    verify_serp_parsing(
        "https://web.archive.org/web/20210224171904id_/https://scholar.google.com/scholar?hl=en&q=Wan%2C+Y.%2C+Menon%2C+S.%2C+and+Ramaprasad%2C+A.+2009.+The+paradoxical+nature+of+electronic+decision+aids+on+comparison-shopping%3A+The+experiments+and+analysis.+J.+Theoret.+Appl.+Electron.+Commerce+Res.%2C+80--96.+",
        "google-scholar",
    )


def test_parse_query_google_crow_names_1608438374():
    verify_serp_parsing(
        "https://web.archive.org/web/20201220042614id_/https://www.google.com/search?q=crow+names&rlz=1C1GCEA_enCA828CA828&oq=crow+name&aqs=chrome.0.0i457j69i57j0l6.1630j0j7&sourceid=chrome&ie=UTF-8",
        "google",
    )


def test_parse_query_google_giulia_botti_1660836463():
    verify_serp_parsing(
        "https://web.archive.org/web/20220818152743id_/https://www.google.com/search?as_eq=wikipedia&q=%22Giulia+Botti%22",
        "google",
    )


def test_parse_query_google_luiz_carlos_footballer_born_1980_wikipedia_1637131910():
    verify_serp_parsing(
        "https://web.archive.org/web/20211117065150id_/https://www.google.com/search?q=%22Luiz+Carlos%22+footballer,+born+1980+-wikipedia&gbv=1&sei=Gv2OYYXOMIHB-wTkppewDg",
        "google",
    )


def test_parse_query_google_now_it_s_time_for_your_treatment_relax_make_yourself_comfortable_1427746605():
    verify_serp_parsing(
        "https://web.archive.org/web/20150330201645id_/https://www.google.com/search?q=%22Now%2C+it%27s+time+for+your+treatment.+Relax%2C+make+yourself+comfortable.%22&oq=%22Now%2C+it%27s+time+for+your+treatment.+Relax%2C+make+yourself+comfortable.%22&aqs=chrome.0.69i59.536j0j9&sourceid=chrome&es_sm=0&ie=UTF-8",
        "google",
    )


def test_parse_query_google_lucius_vibullius_rufus_son_in_law_of_herodes_atticus_1642439444():
    verify_serp_parsing(
        "https://web.archive.org/web/20220117171044id_/https://www.google.com/search?as_eq=wikipedia&q=%22Lucius+Vibullius+Rufus%22+son-in-law+of+Herodes+Atticus",
        "google",
    )


def test_parse_query_google_la_pipa_1635023533():
    verify_serp_parsing(
        "https://web.archive.org/web/20211023211213id_/https://www.google.com/search?as_eq=wikipedia&q=%22LA+PIPA%22",
        "google",
    )


def test_parse_query_google_forced_labor_in_california_1635373615():
    verify_serp_parsing(
        "https://web.archive.org/web/20211027222655id_/https://www.google.com/search?as_eq=wikipedia&q=%22Forced+labor+in+California%22",
        "google",
    )
