# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_aliexpress_barefoot_accessories_1508385234():
    verify_serp_parsing(
        "https://web.archive.org/web/20171019035354id_/https://www.aliexpress.com/w/wholesale-barefoot-accessories.html?site=glo&g=y&SearchText=barefoot+accessories&pvId=200001034-361187&attrRel=or",
        "aliexpress",
    )


def test_parse_query_aliexpress_sterling_silver_gemstone_1384701071():
    verify_serp_parsing(
        "https://web.archive.org/web/20131117151111id_/http://www.aliexpress.com/wholesale?SearchText=sterling+silver+gemstone&initiative_id=RS_20131116203418",
        "aliexpress",
    )


def test_parse_query_aliexpress_women_messenger_bags_1397198302():
    verify_serp_parsing(
        "https://web.archive.org/web/20140411063822id_/http://www.aliexpress.com/w/wholesale-Women-Messenger-Bags.html?g=y&SearchText=Women%2BMessenger%2BBags&CatId=100002612&pvId=200000329-200004094&shipCountry=us&initiative_id=SB_20130813182932",
        "aliexpress",
    )


def test_parse_query_aliexpress_q5_phone_1374387535():
    verify_serp_parsing(
        "https://web.archive.org/web/20130721061855id_/http://www.aliexpress.com/wholesale/wholesale-q5-phone.html?SearchText=q5%2Bphone&CatId=0&SortType=total_weight_score_desc",
        "aliexpress",
    )


def test_parse_query_aliexpress_sterling_silver_pandora_charms_1457090417():
    verify_serp_parsing(
        "https://web.archive.org/web/20160304112017id_/http://www.aliexpress.com:80/w/wholesale-sterling-silver-pandora-charms.html?site=glo&shipCountry=us&g=y&SearchText=sterling+silver+pandora+charms&pvId=14-496&CatId=200160001",
        "aliexpress",
    )


def test_parse_query_aliexpress_children_school_bag_1388612710():
    verify_serp_parsing(
        "https://web.archive.org/web/20140101214510id_/http://www.aliexpress.com/w/wholesale-CHILDREN-SCHOOL-BAG.html?SearchText=CHILDREN%2BSCHOOL%2BBAG&CatId=380520&initiative_id=SB_20130923225029&SortType=total_weight_score_desc",
        "aliexpress",
    )


def test_parse_query_aliexpress_transmission_shaft_1435605057():
    verify_serp_parsing(
        "https://web.archive.org/web/20150629191057id_/http://www.aliexpress.com/w/wholesale-transmission-shaft.html?SearchText=transmission%2Bshaft&CatId=0&pvId=200001211-2277&shipCountry=us",
        "aliexpress",
    )


def test_parse_query_aliexpress_jewelry_sets_1390214039():
    verify_serp_parsing(
        "https://web.archive.org/web/20140120103359id_/http://www.aliexpress.com/w/wholesale-Jewelry-Sets.html?g=y&SearchText=Jewelry%2BSets&CatId=100006750&pvId=200000785-200003778%2C20252-1551&initiative_id=SB_20130731213711",
        "aliexpress",
    )


def test_parse_query_aliexpress_kids_wear_1293514157():
    verify_serp_parsing(
        "https://web.archive.org/web/20101228052917id_/http://www.aliexpress.com:80/wholesale?SearchText=kids+wear&CatId=0",
        "aliexpress",
    )


def test_parse_query_aliexpress_waterproof_winter_boots_women_1500418630():
    verify_serp_parsing(
        "https://web.archive.org/web/20170718225710id_/https://www.aliexpress.com/w/wholesale-waterproof-winter-boots-women.html?site=glo&g=y&SearchText=waterproof+winter+boots+women&pvId=200009123-1886&attrRel=or",
        "aliexpress",
    )
