# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_ecosia_financial_risk_tolerance_quiz_1643759873():
    verify_serp_parsing(
        "https://web.archive.org/web/20220201235753id_/https://www.ecosia.org/search?q=financial+risk+tolerance+quiz",
        "ecosia",
    )


def test_parse_query_ecosia_free_file_sharing_services_1638926359():
    verify_serp_parsing(
        "https://web.archive.org/web/20211208011919id_/https://www.ecosia.org/search?q=free+file+sharing+services",
        "ecosia",
    )


def test_parse_query_ecosia_how_to_be_more_generous_1590871266():
    verify_serp_parsing(
        "https://web.archive.org/web/20200530204106id_/https://www.ecosia.org/search?q=how+to+be+more+generous&addon=chrome&addonversion=3.2.0&method=topbar",
        "ecosia",
    )


def test_parse_query_ecosia_west_point_nebraska_1644663254():
    verify_serp_parsing(
        "https://web.archive.org/web/20220212105414id_/https://www.ecosia.org/search?q=west+point+nebraska",
        "ecosia",
    )


def test_parse_query_ecosia_hallam_f_c_1596174558():
    verify_serp_parsing(
        "https://web.archive.org/web/20200731054918id_/https://www.ecosia.org/search?q=Hallam+F.C.",
        "ecosia",
    )


def test_parse_query_ecosia_google_image_scraper_1601781718():
    verify_serp_parsing(
        "https://web.archive.org/web/20201004032158id_/https://www.ecosia.org/search?q=google+image+scraper",
        "ecosia",
    )


def test_parse_query_ecosia_form_1694_instructions_1635977208():
    verify_serp_parsing(
        "https://web.archive.org/web/20211103220648id_/https://www.ecosia.org/search?q=form+1694+instructions",
        "ecosia",
    )


def test_parse_query_ecosia_where_are_my_chrome_extensions_1635276242():
    verify_serp_parsing(
        "https://web.archive.org/web/20211026192402id_/https://www.ecosia.org/search?q=where+are+my+chrome+extensions",
        "ecosia",
    )


def test_parse_query_ecosia_gmail_sign_in_1637276050():
    verify_serp_parsing(
        "https://web.archive.org/web/20211118225410id_/https://www.ecosia.org/search?q=gmail+sign+in",
        "ecosia",
    )


def test_parse_query_ecosia_world_deutsch_regional_europa_deutschland_hessen_landkreise_rheingau_taunus_kreis_stadte_und_gemeind_1595135090():
    verify_serp_parsing(
        "https://web.archive.org/web/20200719050450id_/https://www.ecosia.org/search?q=World+Deutsch+Regional+Europa+Deutschland+Hessen+Landkreise+Rheingau-Taunus-Kreis+St%C3%A4dte+und+Gemeinden+R%C3%BCdesheim+am+Rhein",
        "ecosia",
    )


def test_parse_query_ecosia_how_much_doordash_driver_make_1654857157():
    verify_serp_parsing(
        "https://web.archive.org/web/20220610103237id_/https://www.ecosia.org/search?q=how+much+doordash+driver+make",
        "ecosia",
    )


def test_parse_query_ecosia_virtual_studio_code_download_for_windows_10_1642714491():
    verify_serp_parsing(
        "https://web.archive.org/web/20220120213451id_/https://www.ecosia.org/search?q=virtual+studio+code+download+for+windows+10",
        "ecosia",
    )


def test_parse_query_ecosia_h_and_m_clothing_sale_1635863133():
    verify_serp_parsing(
        "https://web.archive.org/web/20211102142533id_/https://www.ecosia.org/search?q=h+and+m+clothing+sale",
        "ecosia",
    )


def test_parse_query_ecosia_laughter_stories_1640836502():
    verify_serp_parsing(
        "https://web.archive.org/web/20211230035502id_/https://www.ecosia.org/search?q=laughter+stories&addon=chrome&addonversion=4.0.7&method=topbar",
        "ecosia",
    )


def test_parse_query_ecosia_what_is_a_description_1655190914():
    verify_serp_parsing(
        "https://web.archive.org/web/20220614071514id_/https://www.ecosia.org/search?q=what+is+a+description",
        "ecosia",
    )


def test_parse_query_ecosia_macglauglin_1640487447():
    verify_serp_parsing(
        "https://web.archive.org/web/20211226025727id_/https://www.ecosia.org/search?q=macglauglin&addon=chrome&addonversion=4.0.7&method=topbar",
        "ecosia",
    )


def test_parse_query_ecosia_8_ft_to_cm_1629639998():
    verify_serp_parsing(
        "https://web.archive.org/web/20210822134638id_/https://www.ecosia.org/search?q=8+ft+to+cm&addon=chrome&addonversion=3.4.0&method=topbar",
        "ecosia",
    )


def test_parse_query_ecosia_how_to_check_if_a_value_is_null_in_c_1639813391():
    verify_serp_parsing(
        "https://web.archive.org/web/20211218074311id_/https://www.ecosia.org/search?tt=e8eb07a6&q=how+to+check+if+a+value+is+null+in+C%2B%2B&addon=brave",
        "ecosia",
    )


def test_parse_query_ecosia_we_will_rock_you_23yt_1587407460():
    verify_serp_parsing(
        "https://web.archive.org/web/20200420183100id_/https://www.ecosia.org/search?q=We+Will+Rock+You%2523yt",
        "ecosia",
    )


def test_parse_query_ecosia_health_conditions_and_diseases_neurological_disorders_meningitis_1666663445():
    verify_serp_parsing(
        "https://web.archive.org/web/20221025020405id_/https://www.ecosia.org/search?q=Health+Conditions+and+Diseases+Neurological+Disorders+Meningitis",
        "ecosia",
    )


def test_parse_query_ecosia_barnes_1636235793():
    verify_serp_parsing(
        "https://web.archive.org/web/20211106215633id_/https://www.ecosia.org/search?+Noble=&amp=&filters=sid%3A%22dd4a6430-b264-14e7-06d4-0c88211ae6fa%22&q=Barnes+",
        "ecosia",
    )


def test_parse_query_ecosia_saltpeter_beds_1643653808():
    verify_serp_parsing(
        "https://web.archive.org/web/20220131183008id_/https://www.ecosia.org/search?q=saltpeter+beds&addon=chrome&addonversion=4.0.7&method=topbar",
        "ecosia",
    )


def test_parse_query_ecosia_whiteman_afb_public_affairs_1636203076():
    verify_serp_parsing(
        "https://web.archive.org/web/20211106125116id_/https://www.ecosia.org/search?q=whiteman+afb+public+affairs",
        "ecosia",
    )


def test_parse_query_ecosia_can_you_show_smoking_on_tv_1624555764():
    verify_serp_parsing(
        "https://web.archive.org/web/20210624172924id_/https://www.ecosia.org/search?q=can+you+show+smoking+on+tv&addon=chrome&addonversion=3.4.0&method=topbar",
        "ecosia",
    )


def test_parse_query_ecosia_what_does_god_do_to_tratorirs_1590883066():
    verify_serp_parsing(
        "https://web.archive.org/web/20200530235746id_/https://www.ecosia.org/search?q=what+does+God+do+to+tratorirs&addon=chrome&addonversion=3.2.0&method=topbar",
        "ecosia",
    )


def test_parse_query_ecosia_windows_11_activator_reddit_1637172885():
    verify_serp_parsing(
        "https://web.archive.org/web/20211117181445id_/https://www.ecosia.org/search?q=windows+11+activator+reddit",
        "ecosia",
    )


def test_parse_query_ecosia_git_create_pull_request_1655702772():
    verify_serp_parsing(
        "https://web.archive.org/web/20220620052612id_/https://www.ecosia.org/search?q=git+create+pull+request",
        "ecosia",
    )


def test_parse_query_ecosia_hm_219c_1637494750():
    verify_serp_parsing(
        "https://web.archive.org/web/20211121113910id_/https://www.ecosia.org/search?q=hm+219c",
        "ecosia",
    )


def test_parse_query_ecosia_deaf_community_1626760345():
    verify_serp_parsing(
        "https://web.archive.org/web/20210720055225id_/https://www.ecosia.org/search?q=deaf+community&addon=chrome&addonversion=3.4.0&method=topbar",
        "ecosia",
    )


def test_parse_query_ecosia_world_deutsch_regional_europa_deutschland_baden_wurttemberg_stadte_und_gemeinden_karlsruhe_1621530240():
    verify_serp_parsing(
        "https://web.archive.org/web/20210520170400id_/https://www.ecosia.org/search?q=World+Deutsch+Regional+Europa+Deutschland+Baden-W%C3%BCrttemberg+St%C3%A4dte+und+Gemeinden+Karlsruhe",
        "ecosia",
    )


def test_parse_query_ecosia_fudanshi_1655238275():
    verify_serp_parsing(
        "https://web.archive.org/web/20220614202435id_/https://www.ecosia.org/search?q=fudanshi",
        "ecosia",
    )


def test_parse_query_ecosia_why_can_t_you_order_international_nail_polish_online_india_23a_1586448930():
    verify_serp_parsing(
        "https://web.archive.org/web/20200409161530id_/https://www.ecosia.org/search?q=why+can%27t+you+order+international+nail+polish+online+india%2523a",
        "ecosia",
    )


def test_parse_query_ecosia_coding_freelancing_1634534706():
    verify_serp_parsing(
        "https://web.archive.org/web/20211018052506id_/https://www.ecosia.org/search?tt=e8eb07a6&q=coding+freelancing&addon=brave",
        "ecosia",
    )


def test_parse_query_ecosia_vasectomy_reversal_success_rate_23yt_1623229800():
    verify_serp_parsing(
        "https://web.archive.org/web/20210609091000id_/https://www.ecosia.org/search?q=vasectomy+reversal+success+rate%2523yt",
        "ecosia",
    )


def test_parse_query_ecosia_hisotry_of_tomato_in_india_23yt_1591696836():
    verify_serp_parsing(
        "https://web.archive.org/web/20200609100036id_/https://www.ecosia.org/search?q=hisotry+of+tomato+in+india%2523yt",
        "ecosia",
    )


def test_parse_query_ecosia_gnome_desktop_entry_1655209403():
    verify_serp_parsing(
        "https://web.archive.org/web/20220614122323id_/https://www.ecosia.org/search?q=gnome+desktop+entry",
        "ecosia",
    )


def test_parse_query_ecosia_game_changer_classic_1638948940():
    verify_serp_parsing(
        "https://web.archive.org/web/20211208073540id_/https://www.ecosia.org/search?q=game+changer+classic",
        "ecosia",
    )


def test_parse_query_ecosia_harry_styles_siblings_1634695267():
    verify_serp_parsing(
        "https://web.archive.org/web/20211020020107id_/https://www.ecosia.org/search?q=harry+styles+siblings",
        "ecosia",
    )


def test_parse_query_ecosia_what_s_the_shortest_war_ever_1635275630():
    verify_serp_parsing(
        "https://web.archive.org/web/20211026191350id_/https://www.ecosia.org/search?q=what%27s+the+shortest+war+ever",
        "ecosia",
    )


def test_parse_query_ecosia_sin_is_an_ugly_creature_1590737798():
    verify_serp_parsing(
        "https://web.archive.org/web/20200529073638id_/https://www.ecosia.org/search?q=sin+is+an+ugly+creature&addon=chrome&addonversion=3.2.0&method=topbar",
        "ecosia",
    )


def test_parse_query_ecosia_high_functioning_depression_23w_1615448305():
    verify_serp_parsing(
        "https://web.archive.org/web/20210311073825id_/https://www.ecosia.org/search?q=high+functioning+depression%2523w",
        "ecosia",
    )


def test_parse_query_ecosia_correct_way_to_wash_hair_oily_scalp_1588676008():
    verify_serp_parsing(
        "https://web.archive.org/web/20200505105328id_/https://www.ecosia.org/search?q=correct+way+to+wash+hair+oily+scalp&addon=chrome&addonversion=3.1.2",
        "ecosia",
    )


def test_parse_query_ecosia_by_talos_this_cant_be_happening_1630519906():
    verify_serp_parsing(
        "https://web.archive.org/web/20210901181146id_/https://www.ecosia.org/search?q=%22by+talos+this+can%E2%80%99t+be+happening%22&addon=chrome&addonversion=3.4.0&method=topbar",
        "ecosia",
    )


def test_parse_query_ecosia_foot_to_centimeter_1612629786():
    verify_serp_parsing(
        "https://web.archive.org/web/20210206164306id_/https://www.ecosia.org/search?q=foot+to+centimeter",
        "ecosia",
    )


def test_parse_query_ecosia_percy_jackson_s_greek_gods_1634509308():
    verify_serp_parsing(
        "https://web.archive.org/web/20211017222148id_/https://www.ecosia.org/search?tt=e8eb07a6&q=percy+jackson%27s+greek+gods&addon=brave",
        "ecosia",
    )


def test_parse_query_ecosia_average_amount_of_photos_you_could_take_on_a_camera_in_1940_s_1572660962():
    verify_serp_parsing(
        "https://web.archive.org/web/20191102021602id_/https://www.ecosia.org/search?q=average+amount+of+photos+you+could+take+on+a+camera+in+1940%27s&addon=chrome&addonversion=2.1.0",
        "ecosia",
    )


def test_parse_query_ecosia_dall_e_1654952788():
    verify_serp_parsing(
        "https://web.archive.org/web/20220611130628id_/https://www.ecosia.org/search?tt=e8eb07a6&q=dall+e&addon=brave",
        "ecosia",
    )


def test_parse_query_ecosia_grady_white_ce_251_1636884788():
    verify_serp_parsing(
        "https://web.archive.org/web/20211114101308id_/https://www.ecosia.org/search?q=grady+white+ce+251",
        "ecosia",
    )


def test_parse_query_ecosia_windows_for_workgroups_3_11_iso_1644191359():
    verify_serp_parsing(
        "https://web.archive.org/web/20220206234919id_/https://www.ecosia.org/search?q=windows+for+workgroups+3.11+iso",
        "ecosia",
    )


def test_parse_query_ecosia_watch_tv_series_23g_1602851877():
    verify_serp_parsing(
        "https://web.archive.org/web/20201016123757id_/https://www.ecosia.org/search?q=watch+tv+series%2523g",
        "ecosia",
    )
