# flake8: noqa
# This file is auto-generated by generate_tests.py.
from archive_query_log.legacy.results.test.test_utils import verify_serp_parsing


def test_parse_query_xvideos_drunk_1325431509():
    verify_serp_parsing(
        "https://web.archive.org/web/20120101152509id_/http://www.xvideos.com:80/?k=drunk",
        "xvideos",
    )


def test_parse_query_xvideos_escola_sao_luis_1657929903():
    verify_serp_parsing(
        "https://web.archive.org/web/20220716000503id_/https://www.xvideos.com/?k=escola+s%C3%A3o+lu%C3%ADs&sort=relevance&datef=all",
        "xvideos",
    )


def test_parse_query_xvideos_free_hardcore_porn_videos_japanese_video_1428541087():
    verify_serp_parsing(
        "https://web.archive.org/web/20150409005807id_/http://www.xvideos.com/?k=free-hardcore-porn-videos+japanese+video",
        "xvideos",
    )


def test_parse_query_xvideos_gay_whitezilla_go_to_www_lovesbo_ru_1643416941():
    verify_serp_parsing(
        "https://web.archive.org/web/20220129004221id_/https://www.xvideos.com/?k=gay+whitezilla+%E2%8F%A9+go+to+%E2%9D%A4%EF%B8%8F%EF%B8%8F+www.lovesbo.ru&sort=relevance&datef=week&typef=gay",
        "xvideos",
    )


def test_parse_query_xvideos_robber_1248193170():
    verify_serp_parsing(
        "https://web.archive.org/web/20090721161930id_/http://www.xvideos.com:80/?k=robber",
        "xvideos",
    )


def test_parse_query_xvideos_casey_cavert_go_to_www_lovesbo_ru_1642784433():
    verify_serp_parsing(
        "https://web.archive.org/web/20220121170033id_/https://www.xvideos.com/?k=casey+cavert+%E2%8F%A9+go+to+%E2%9D%A4%EF%B8%8F%EF%B8%8F+www.lovesbo.ru&sort=relevance&datef=week",
        "xvideos",
    )


def test_parse_query_xvideos_gay_peeing_porn_go_to_www_lovesbo_ru_1643357466():
    verify_serp_parsing(
        "https://web.archive.org/web/20220128081106id_/https://www.xvideos.com/?k=gay+peeing+porn+%E2%8F%A9+go+to+%E2%9D%A4%EF%B8%8F%EF%B8%8F+www.lovesbo.ru&sort=rating&typef=gay",
        "xvideos",
    )


def test_parse_query_xvideos_evander_marius_go_to_www_lovesbo_ru_1642716634():
    verify_serp_parsing(
        "https://web.archive.org/web/20220120221034id_/https://www.xvideos.com/?k=evander+marius+%E2%8F%A9+go+to+%E2%9D%A4%EF%B8%8F%EF%B8%8F+www.lovesbo.ru&sort=relevance&datef=3month",
        "xvideos",
    )


def test_parse_query_xvideos_claire_dames_1325320932():
    verify_serp_parsing(
        "https://web.archive.org/web/20111231084212id_/http://www.xvideos.com:80/?k=claire+dames",
        "xvideos",
    )


def test_parse_query_xvideos_solo_1341894522():
    verify_serp_parsing(
        "https://web.archive.org/web/20120710042842id_/http://www.xvideos.com:80/?k=solo&sort=relevance&durf=1-3min&datef=all",
        "xvideos",
    )
